/**
 * \file gre/lrformula.h
 * \brief GRE_LAYER_FORMULA definitions
 *
 * \if NODOC
 * $Id: lrformula.h_v 1.8 2013/02/15 20:51:35 mju Exp $
 *
 * $Log: lrformula.h_v $
 * Revision 1.8  2013/02/15 20:51:35  mju
 * Fix dox hdr.
 *
 * Revision 1.7  2006/12/21 18:15:41  mju
 * Remove legacy rvc usages from geoformula class.
 *
 * Revision 1.6  2006/10/18 14:16:23  mju
 * Use colorbal hdr.
 *
 * Revision 1.5  2006/09/15 15:30:20  mju
 * Serializer changes.
 *
 * Revision 1.4  2005/10/26 20:45:00  mju
 * Use gre namespace instead of legacy types.
 *
 * Revision 1.3  2005/10/14 17:31:12  mju
 * GRE namespace and treeview.
 *
 * Revision 1.2  2005/02/28 18:11:37  scowan
 * Support layer copy virtual method.
 *
 * Revision 1.1  2005/01/20 16:56:25  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_GRE_LRFORMULA_H
#define	INC_GRE_LRFORMULA_H

#ifndef	INC_GRE_LAYER_H
	#include <gre/layer.h>
#endif

#ifndef	INC_MI32_GEOFRMLA_H
	#include <mi32/geofrmla.h>
#endif

#ifndef	INC_MI32_COLORBAL_H
	#include <mi32/colorbal.h>
#endif

namespace GRE {
//===================================================================================================================

class LAYER_FORMULA : public GRE::LAYER {
	public:

		// LAYER_FORMULA::DISPPARM
		class DISPPARM : public GRE::LAYER::DISPPARM {
			public:

				class DLG;

				GEOFORMULA Formula;
				CBPARMS ColorBalance;		//!< For adjusting color

				DISPPARM ();
				DISPPARM (
					const DISPPARM& rhs
					): GRE::LAYER::DISPPARM(rhs) { Copy(rhs); }
				virtual ~DISPPARM (
					) { Free(); }

				//! Assignment.
				DISPPARM& operator= (
					const DISPPARM& rhs
					) { if (this != &rhs) { Free(); Copy(rhs); } return (*this); }

			protected:
				virtual const SERIALIZERITEM* SerialGetItemDef (SERIALIZER& serializer) const;

			private:
				#ifndef GENERATING_DOXYGEN_OUTPUT
				static ERRVALUE SerializerCB_Formula (SERIALIZER&, const SERIALIZERITEM*, void*, SERIALIZERITEM::ACTION);
				void CloseObject ();
				void Copy (const DISPPARM&);
				void Free ();
				#endif // GENERATING_DOXYGEN_OUTPUT
			};	// End of LAYER_FORMULA::DISPPARM

		//! Register this layer type
		static void RegisterType (
			);

		//! Construct layer and insert into list
		explicit LAYER_FORMULA (
			GRE::GROUP *group,										//!< Group to contain layer
			CREATEFLAGS createflags = CREATEFLAG_None,	//!< Creation flags
			GRE::LISTPOS listpos = GRE::LISTPOS_Last,		//!< Position in list
			GRE::LAYER *reflayer = 0								//!< Reference layer for insertion
			);

		virtual ~LAYER_FORMULA ();

		//! Retrieve layer-specific display parameters.
		const DISPPARM& GetDispParm (
			) const { return (m_dispparm); }

		//! Set layer-specific display parameters.
		//! This is the recommended method for changing how an existing layer is to be
		//! rendered.  Validation will be performed on the specified parameters and
		//! adjustments made to the layer's copy if necessary.  Use of this method
		//! usually result in a ChangeBegin / ChangeEnd message pair, and will also
		//! generate a ChangeObject message if the spatial object used in the layer
		//! is changed.
		ERRVALUE SetDispParm (
			const DISPPARM& dispparm					//!< Parameters to set
			);

	protected:

		DISPPARM m_dispparm;								//!< Layer-specific display parameters

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT

		ERRVALUE Draw2D (GRE::LAYERDC& layerdc);
		ERRVALUE Draw3D (GRE::LAYERDC& layerdc);

		//! Overrides from GRE::LAYER.
	#ifdef USE_MGUI
		virtual int v_ControlPanel (MDLGPARENT dlgparent,UINT32 flags = 0);
	#endif
		virtual GRE::LAYER* v_Copy (GRE::GROUP *group) const;
		virtual ERRVALUE v_Draw (GRE::LAYERDC& layerdc);
		virtual bool v_HasNullImageCells () const;
		virtual const char* v_SerialGetTagName () const;
		virtual void v_SetDftName (bool ReplaceExisting);
		virtual ERRVALUE v_TemplateRead (SERIALIZER& serializer);
		virtual int v_UpdateExtents (bool forceupdate);

		LAYER_FORMULA (const LAYER_FORMULA&);
		LAYER_FORMULA& operator= (const LAYER_FORMULA&);

		#endif // GENERATING_DOXYGEN_OUTPUT
	};


//===================================================================================================================
}	// End namespace GRE

#endif	// INC_GRE_LRFORMULA_H
