/**
 * \file <mgui/gadgetimage.h>
 * \brief MGUI::GADGET_IMAGE definitions
 *
 * \if NODOC
 * $Id: gadgetimage.h_v 1.2 2011/12/30 14:28:00 mju Exp $
 *
 * $Log: gadgetimage.h_v $
 * Revision 1.2  2011/12/30 14:28:00  mju
 * Use canvasdevice_Memory.
 *
 * Revision 1.1  2011/03/21 20:29:24  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_MGUI_GADGETIMAGE_H
#define	INC_MGUI_GADGETIMAGE_H

#ifndef	INC_MGUI_GADGET_H
#include <mgui/gadget.h>
#endif

#ifndef	INC_SPATMOD_IMAGESTAGEAUTOPTR_H
#include <spatmod/imagestageautoptr.h>
#endif

#ifndef	INC_MI32_MISTRING_H
#include <mi32/mistring.h>
#endif

namespace MGUI {

//=====================================================================================================================

//! Simple image gadget with source from pipeline and tooltip support.
class GADGET_IMAGE : public MGUI::GADGET {
	public:

		//! Contructor.
		GADGET_IMAGE (
			MGUI::TOOLCANVAS *pCanvas,			//!< Canvas to contain gadget
			PLACEMENT PlacementsAllowed,		//!< Allowed placements
			FLAGS flags = FLAG_None,
			CANVASDEVICES CanvasDevices = CANVASDEVICE_Memory
			);

		//! Destructor.
		~GADGET_IMAGE ();

		//! Set image.
		//! If caller retains ownership the specified stage must exist for the life of the gadget.
		void SetImage (
			SPATMOD::IMAGE::STAGE *pStage,	//!< Pointer to stage
			bool TakeOwnership					//!< Whether to take ownership
			) { m_StagePtr.Assign(pStage,TakeOwnership); }

		//! Set tooltip string.
		void SetToolTip (
			const MISTRING& tooltip
			) { m_ToolTip = tooltip; }

		//! Set whether to use alpha blending when drawing.
		void SetUseAlphaBlend (
			bool UseAlphaBlend = true
			) { m_UseAlphaBlend = UseAlphaBlend; }

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT

		SPATMOD::IMAGE::STAGE_AUTOPTR m_StagePtr;
		MISTRING m_ToolTip;
		bool m_UseAlphaBlend;

		// GADGET overrides
		virtual MGUI::POINT v_ComputeSize ();
		virtual void v_Draw (MGD::CONTEXT *gc, MGUI::CANVAS::DEVICETYPE DeviceType);
		virtual bool v_OnToolTipRequest (MGUI::CTRL_TOOLTIP& tooltip, MGUI::POINT& ptCanvas);
		#endif
	};

//=====================================================================================================================

}	// End namespace MGUI

#endif	// INC_MGUI_GADGETIMAGE_H
