/**
 * \file mgui/scrollbar.h
 * \brief MGUI::CTRL_SCROLLBAR definitions
 *
 * \if NODOC
 * $Id: scrollbar.h_v 1.1 2008/09/19 13:53:22 mju Exp $
 *
 * $Log: scrollbar.h_v $
 * Revision 1.1  2008/09/19 13:53:22  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_MGUI_SCROLLBAR_H
#define	INC_MGUI_SCROLLBAR_H

#ifndef	INC_MGUI_CTRL_H
#include <mgui/ctrl.h>
#endif

namespace MGUI {
//===================================================================================================================

//! ScrollBar control.
class CTRL_SCROLLBAR : public MGUI::CTRL {
	public:

		enum ORIENTATION {
			ORIENTATION_Horizontal,
			ORIENTATION_Vertical
			};

		//! Constructor.
		CTRL_SCROLLBAR (
			);

		//! Destructor.
		virtual ~CTRL_SCROLLBAR (
			);

		//! Create scrollbar control.
		void Create (
			MGUI::LAYOUT_PANE_BASE& ParentPane,		//!< Parent pane
			ORIENTATION orientation						//!< Orientation
			);

		//! Get slider position.
		INT32 GetPosition (
			) const;

		//! Set delegate to call after position changed.
		void SetDelegateOnChangePosition (
			DELEGATE_VOID_INT32 delegate
			) { m_DelegateOnChangePosition = delegate; }

		//! Set delegate to call while user drags slider.
		//! If no delegate is set, position changes will only be reported after pointer button is released.
		void SetDelegateOnDrag (
			DELEGATE_VOID_INT32 delegate
			) { m_DelegateOnDrag = delegate; }

		//! Set slider position.
		void SetPosition (
			INT32 position,					//!< New position
			bool notify = true				//!< Notify via "change position" delegate if position changed
			);

		//! Set all values.
		void SetValues (
			INT32 position,					//!< New position
			INT32 minvalue,					//!< Minimum value
			INT32 maxvalue,					//!< Maximum value
			INT32 pagesize,					//!< Page size (used to determine slider length)
			INT32 stepincrement = 1,		//!< Increment for when user clicks on arrows or scrolls with pointer wheel
			INT32 pageincrement = 0,		//!< Increment when user clicks in "trough", <= 0 use 90% of pagesize
			bool notify = true				//!< Notify via "change position" delegate that values are changed
			);

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT
		DELEGATE_VOID_INT32 m_DelegateOnChangePosition;
		DELEGATE_VOID_INT32 m_DelegateOnDrag;

		#ifdef X_NATIVE
		static void CB_Drag (Widget, CTRL_SCROLLBAR*, void*);
		static void CB_ValueChanged (Widget, CTRL_SCROLLBAR*, void*);
		#endif

		void NotifyChangePosition (
			INT32 position
			) { if (m_DelegateOnChangePosition != 0) m_DelegateOnChangePosition(position); }

		void NotifyDrag (
			INT32 position
			) { if (m_DelegateOnDrag != 0) m_DelegateOnChangePosition(position); }

		CTRL_SCROLLBAR (const CTRL_SCROLLBAR&);
		CTRL_SCROLLBAR& operator= (const CTRL_SCROLLBAR&);
		#endif // GENERATING_DOXYGEN_OUTPUT
	};

//===================================================================================================================
} // End namespace MGUI

#endif	// INC_MGUI_SCROLLBAR_H

