/**
 * \file mgui/toolsegment.h
 * \brief MGUI::TOOL_SEGMENT class definition
 *
 * \if NODOC
 * $Id: toolsegment.h_v 1.10 2011/12/09 20:23:43 mju Exp $
 *
 * $Log: toolsegment.h_v $
 * Revision 1.10  2011/12/09 20:23:43  mju
 * No context in v_draw.
 *
 * Revision 1.9  2009/07/08 15:55:19  mju
 * Add manual controls.
 *
 * Revision 1.8  2008/02/14 18:38:33  mju
 * Add setStart/End.
 *
 * Revision 1.7  2008/02/01 15:01:47  mju
 * Change button handlers to return bool.
 *
 * Revision 1.6  2008/01/04 18:59:55  mju
 * Generalize pointer button methods.
 *
 * Revision 1.5  2007/12/21 22:08:17  mju
 * Add v_generateRegion.
 *
 * Revision 1.4  2007/10/05 21:12:31  mju
 * Rename inclusion guards.
 *
 * Revision 1.3  2003/10/03 19:58:19  linux32build!build
 * Doxygen
 *
 * Revision 1.2  2003/09/15 13:49:32  fileserver!dwilliss
 * Doxygen
 *
 * Revision 1.1  2003/01/10 23:09:19  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_MGUI_TOOLSEGMENT_H
#define	INC_MGUI_TOOLSEGMENT_H

#ifndef	INC_MGUI_TOOLBASE_H
#include <mgui/toolbase.h>
#endif

namespace MGUI {


//! Graphic "segment" tool.
class TOOL_SEGMENT : public TOOL_LIMITED {
	public:

		//! Constructor.
		explicit TOOL_SEGMENT (
			TOOLCANVAS *canvas
			);

		//! Destructor.
		virtual ~TOOL_SEGMENT ();

		//! Get segment end point coordinates.
		const DPOINT2D& GetEnd (
			) const { return (m_endpoint); }

		//! Get segment start point coordinates
		const DPOINT2D& GetStart (
			) const { return (m_startpoint); }

		//! Set ending point.
		void SetEnd (
			const DPOINT2D& ptEnd
			);

		//! Set markers for start and end points.
		void SetMarkers (
			MARKER startmarker,						//!< Starting point marker type
			MARKER endmarker,							//!< Ending point marker type
			UINT16 startmarkersize = 0,			//!< Starting point marker size, 0 to retain current size
			UINT16 endmarkersize = 0				//!< Ending point marker size, 0 to retain current size
			);

		//! Set start and end points.
		void SetPoints (
			const DPOINT2D& ptStart,
			const DPOINT2D& ptEnd
			);

		//! Set starting point.
		void SetStart (
			const DPOINT2D& ptStart
			);

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT
		// Enumeration constants
		enum ZONE {
			ZONE_NoFunction = 0,
			ZONE_Outside,
			ZONE_Inside,
			ZONE_Start,
			ZONE_End
			};
		class MANUAL_SEGMENT;
		// Tool settings
		MARKER m_startmarker;
		MARKER m_endmarker;
		UINT16 m_startmarkersize;
		UINT16 m_endmarkersize;
		// Tool position values
		DPOINT2D m_endpoint;
		DPOINT2D m_startpoint;
		// Values used during interaction
		ZONE m_CursorZone;						// Current cursor zone
		DPOINT2D m_prevpt;						// Previous point during button-down
		UINT8 m_AdjustMode;						// Adjustment mode, 2=rotate, 1=everything else

		// Methods
		void AdjustTool (const DPOINT2D&, bool firsttime=false);
		void ComputeCursorZone (const DPOINT2D&);
		void StartTool (const DPOINT2D&);
		void UpdateCursor () const;

		// TOOL_BASE overrides.
		virtual MANUAL_BASE* v_CreateManualBase ();
		virtual void v_DoDraw ();
		virtual void v_DoMove (double dx, double dy, ADJUSTFLAGS flags);
		virtual int v_GenerateRegion (REGION2D& region) const;
		virtual bool v_OnPointerButtonDown (MGUI::POINT point, POINTERBUTTON button, KEYSTATE keystate);
		virtual void v_OnPointerMove (MGUI::POINT point, POINTERBUTTON button, KEYSTATE keystate);
		#endif // GENERATING_DOXYGEN_OUTPUT
	};


}	// End namespace MGUI


#endif	// INC_MGUI_TOOLSEGMENT_H
