/**
 * \file mi32/charencoding.h
 * \brief Enumerations for character encodings
 *
 * \if NODOC
 * $Id: charencoding.h_v 1.3 2011/09/06 21:28:44 mju Exp $
 *
 * $Log: charencoding.h_v $
 * Revision 1.3  2011/09/06 21:28:44  mju
 * Rename macro.
 *
 * Revision 1.2  2006/10/10 17:50:19  dwilliss
 * Added CP932
 *
 * Revision 1.1  2006/06/14 14:30:01  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_MI32_CHARENCODING_H
#define	INC_MI32_CHARENCODING_H

#ifndef INC_MI32_STDDEFNS_H
#include <mi32/stddefns.h>
#endif


//! A character encoding exactly specifies both the set(s) of characters used
//! and how they are stored in memory (assuming native byte order).  Note that
//! this is *not* the same as a CHARSET.  Once an encoding value is assigned
//! it must never be changes as the value may be stored in a data file and is
//! also passed to the misystem DLL.
//!
//! These values should NOT be considered sequential!

#ifndef __cplusplus
typedef
#endif
enum CHAR_ENCODING {
	// Base encodings
	CHAR_ENCODING_ASCII = 0,				//!< ASCII
	CHAR_ENCODING_Unicode,					//!< 2 byte encoding
	CHAR_ENCODING_UTF8,
	CHAR_ENCODING_XResFile,					//!< Variation on ISO-2022
	CHAR_ENCODING_Unicode_Decomposed,	//!< 2 byte encoding, but things like O with Umlat converted to 2 chars, and O and an Umlat
	CHAR_ENCODING_UTF8_Decomposed,		//!< Unicode_Decomposed converted to UTF8
	CHAR_ENCODING_WindowsMultiByte,		//!< WINDOWS ONLY - Uses MultiByteToWideChar/WideCharToMultiByte

	// ISO Encodings
	CHAR_ENCODING_ISO_2022 = 100,
	CHAR_ENCODING_ISO_8859_1,
	CHAR_ENCODING_ISO_8859_2,
	CHAR_ENCODING_ISO_8859_3,
	CHAR_ENCODING_ISO_8859_4,
	CHAR_ENCODING_ISO_8859_5,
	CHAR_ENCODING_ISO_8859_6,
	CHAR_ENCODING_ISO_8859_7,
	CHAR_ENCODING_ISO_8859_8,
	CHAR_ENCODING_ISO_8859_9,

	// Japanese encodings
	CHAR_ENCODING_JIS = 120,		//!< Japanese JIS
	CHAR_ENCODING_EUC,				//!< Japenese EUC
	CHAR_ENCODING_SJIS,				//!< Japanese Shift-JIS
	CHAR_ENCODING_Japanese,			//!< Will gusss which of the 3 Japanese encodings
	CHAR_ENCODING_CP932,				//!< Shift-JIS with Microsoft extensions

	// Chinese encodings
	CHAR_ENCODING_Big5 = 130,		//!< Chinese
	CHAR_ENCODING_GB_2312,			//!< Chinese

	// Korean encodings
	CHAR_ENCODING_KCS_5601 = 140,			//!< Korean

	// ISCII (Indic) Encodings
	CHAR_ENCODING_ISCII_Devanagari = 150,
	CHAR_ENCODING_ISCII_Bengali,
	CHAR_ENCODING_ISCII_Gurmukhi,
	CHAR_ENCODING_ISCII_Gujarati,
	CHAR_ENCODING_ISCII_Oriya,
	CHAR_ENCODING_ISCII_Tamil,
	CHAR_ENCODING_ISCII_Telugu,
	CHAR_ENCODING_ISCII_Kannada,
	CHAR_ENCODING_ISCII_Malayalam,
	
	// Windows Code Pages
	CHAR_ENCODING_WinCP_ANSI = 300,		//!< Most English and Western Europe
	CHAR_ENCODING_WinCP_Cyrl,				//!< Russian
	CHAR_ENCODING_WinCP_Greek,
	CHAR_ENCODING_WinCP_Arabic,
	CHAR_ENCODING_WinCP_Thai,
	CHAR_ENCODING_WinCP_EE,
	CHAR_ENCODING_WinCP_Turk,
	CHAR_ENCODING_WinCP_Hebr,

	// IBM Code Pages
	CHAR_ENCODING_IBMCP_855 = 400,
	CHAR_ENCODING_IBMCP_869,

	// DOS Code Pages
	CHAR_ENCODING_DOSCP_437 = 500,
	CHAR_ENCODING_DOSCP_850,
	CHAR_ENCODING_DOSCP_852,
	CHAR_ENCODING_DOSCP_857,
	CHAR_ENCODING_DOSCP_861,
	CHAR_ENCODING_DOSCP_863,
	CHAR_ENCODING_DOSCP_865,

	// Macintosh Encodings
	CHAR_ENCODING_MacArabic = 600,
	CHAR_ENCODING_MacCroatian,
	CHAR_ENCODING_MacCyrillic,
	CHAR_ENCODING_MacDingbats,
	CHAR_ENCODING_MacCentEurope,
	CHAR_ENCODING_MacGreek,
	CHAR_ENCODING_MacHebrew,
	CHAR_ENCODING_MacIcelandic,
	CHAR_ENCODING_MacJapanese,
	CHAR_ENCODING_MacRomanian,
	CHAR_ENCODING_MacRoman,
	CHAR_ENCODING_MacSymbol,
	CHAR_ENCODING_MacThai,
	CHAR_ENCODING_MacTurkish,
	CHAR_ENCODING_MacUkrainian,

	// Misc Code Pages
	CHAR_ENCODING_KOI8 = 700

	}
#ifndef __cplusplus
	CHAR_ENCODING
#endif
	;

//! Enums which can be used when getting  the list of encodings
#ifndef __cplusplus
typedef
#endif
enum ENCODELIST_FLAGS {
	ENCODELIST_FLAG_Any			= 0x0000,
	ENCODELIST_FLAG_Importable = 0x0001,
	ENCODELIST_FLAG_Exportable = 0x0002,
	ENCODELIST_FLAG_Both		 	= 0x0003,		//!< Importable | Exportable
	ENCODELIST_FLAG_NoUnicode	= 0x0004
	}
#ifndef __cplusplus
	ENCODELIST_FLAGS
#endif
	;

#ifndef GENERATING_DOXYGEN_OUTPUT
#ifdef __cplusplus
// Following only defined for C++
DEFINE_ENUM_OP_BITWISE(ENCODELIST_FLAGS)
#endif
#endif


#endif	// INC_MI32_CHARENCODING_H
