/**
 * \file iconid.h <mi32/iconid.h>
 * \brief MGUI::ICONID enumerations
 *
 * \if NODOC
 * $Id: iconid.h_v 1.187 2013/02/21 14:37:04 mju Exp $
 *
 * $Log: iconid.h_v $
 * Revision 1.187  2013/02/21 14:37:04  mju
 * Add select_by_query_cyan.
 *
 * Revision 1.186  2012/12/19 18:23:54  mju
 * *** empty log message ***
 *
 * Revision 1.185  2012/11/30 17:43:59  mju
 * *** empty log message ***
 *
 * Revision 1.184  2012/11/29 16:54:25  mju
 * Add featuremap items.
 *
 * Revision 1.183  2012/07/18 20:49:25  mju
 * Add georef_select_hard_edge.
 *
 * Revision 1.182  2012/05/31 13:00:49  mju
 * Add draw_point_red.
 *
 * Revision 1.181  2012/05/09 14:05:51  mju
 * Add delete_file/table.
 *
 * Revision 1.180  2012/03/09 15:46:45  bcolombe
 * Add setalllevels, setselectedlevels
 *
 * Revision 1.179  2012/01/27 14:27:14  mju
 * Add icon for terrain tileset.
 *
 * Revision 1.178  2011/11/29 15:58:18  mju
 * Move idi_ defns here so this is only file to edit when adding icon.
 * Simplify instructions accordingly.
 *
 * Revision 1.177  2011/08/29 14:22:33  mju
 * Add text_font.
 *
 * Revision 1.176  2011/08/25 13:05:32  mju
 * Add draw_line_thickness...
 *
 * Revision 1.1  2001/12/14 18:51:59  mju
 * Initial revision
 * \endif
**/

#if !defined(INC_MI32_ICONID_H) || defined(ICONIDTABLE)
#define	INC_MI32_ICONID_H

#ifdef GENERATING_DOXYGEN_OUTPUT		// Fake Doxygen into documenting the ICONID enum

//! Icon ID enumeration.
//!
//! To add a new icon:
//!
//!	1. If the icon does not exist in 'icons.ref', add using the 'dispicon' utility, or have
//!		the graphic designer do so.  Note the icon group/name for later use.
//!
//!	2. Add IDI_ entries to <mi32/iconid.h> for the icon.  New entry should always be 1 greater than the last IDI value.
//!
//!	3. Edit the ICONIDTABLE in <mi32/iconid.h> to add the new icon.  If the icon is a new size
//!		for an existing icon change the ICONIDENTRY to ICONIDENTRY2 or ICONENTRY3 as appropriate.
//!		Otherwise add a new ICONIDENTRY containing the resource name (without the IDI_ prefix),
//!		the icon group and icon name from 'icons.ref'.  Keep items in alphabetical order by
//!		resource name.
//!
//!	4. The X version of the translation is defined in 'micon.c'.  This module will NOT rebuild
//!		automatically after edits to the ICONIDTABLE, so if immediate use of the icon is desired
//!		in an X application you will need to 'touch' the 'micon.c' module before starting a
//!		library build.
enum ICONID {
	};

#else

#define	IDI_FILE_NEW							101
#define	IDI_FILE_OPEN							102
#define	IDI_FILE_SAVE							103
#define	IDI_EDIT_APPLY_RED					104
#define	IDI_EDIT_DELETE_RED					105
#define	IDI_EDIT_UNDO_RED						106
#define	IDI_EDIT_SELECT_RED					107
#define	IDI_EDIT_REDO_RED						108
#define	IDI_ZOOM_UNDO							109
#define	IDI_ZOOM_2								110
#define	IDI_ZOOM_3								111
#define	IDI_ZOOM_4								112
#define	IDI_ZOOM_IN								113
#define	IDI_ZOOM_OUT							114
#define	IDI_ZOOM_1								115
#define	IDI_TOOLBOX_TEXT						116
#define	IDI_TOOLBOX_ARC_WEDGE				117
#define	IDI_TOOLBOX_ARC_CHORD				118
#define	IDI_TOOLBOX_CIRCLE					119
#define	IDI_TOOLBOX_ELLIPSE					120
#define	IDI_TOOLBOX_POINT						121
#define	IDI_TOOLBOX_POLYGON					122
#define	IDI_TOOLBOX_POLYLINE					123
#define	IDI_TOOLBOX_RECTANGLE				124
#define	IDI_TOOLBOX_REGION					125
#define	IDI_TOOLBOX_REGULAR_POLYGON		126
#define	IDI_TOOLBOX_ARC						127
#define	IDI_TOOLBOX_SEGMENT					128
#define	IDI_ZOOM_FULL							129
#define	IDI_VIEW_TOOL_ZOOMBOX				130
#define	IDI_VIEW_TOOL_HYPEREDIT				131
#define	IDI_VIEW_TOOL_HYPERNAVIGATE		132
#define	IDI_VIEW_TOOL_VIEWINVIEW			133
#define	IDI_VIEW_TOOL_GEOTOOLBOX			134
#define	IDI_HYPER_NAVIGATE_HOME				135
#define	IDI_HYPER_NAVIGATE_BACK				136
#define	IDI_FILE_SAVEAS						142
#define	IDI_COMBINE_AREA_SUBTRACT			143
#define	IDI_COMBINE_AREA_UNION				144
#define	IDI_COMBINE_AREA_XOR					145
#define	IDI_FILE_RENAME						146
#define	IDI_COMBINE_AREA_INTERSECT			147
#define	IDI_GRE_LAYER_SURFACE				149
#define	IDI_GRE_LAYER_MAPGRID				150
#define	IDI_GRE_LAYER_PINMAP					151
#define	IDI_GRE_LAYER_SCALEBAR				152
#define	IDI_GRE_LAYER_SCRIPT					153
#define	IDI_GRE_LAYER_GEOFORMULA			154
#define	IDI_GRE_LAYER_WMS						155
#define	IDI_GRE_LAYER_ARCIMS					156
#define	IDI_RVCOBJ_DISP_GROUP				165
#define	IDI_RVCOBJ_COLORPALETTE				166
#define	IDI_RVCOBJ_CONTRAST					167
#define	IDI_RVCOBJ_DATABASE					168
#define	IDI_RVCOBJ_DB_QUERY					169
#define	IDI_RVCOBJ_DB_TABLE					170
#define	IDI_RVCOBJ_DB_TABLE_INTERNAL		171
#define	IDI_RVCOBJ_DB_TABLE_LINKED			172
#define	IDI_RVCOBJ_DB_TABLE_STANDARD		173
#define	IDI_RVCOBJ_CAD							174
#define	IDI_RVCOBJ_RASTER						175
#define	IDI_RVCOBJ_DISP_SIM3D				176
#define	IDI_RVCOBJ_DISP_TEMPLATE			177
#define	IDI_RVCOBJ_FOLDER						178
#define	IDI_RVCOBJ_GEOREFERENCE				179
#define	IDI_RVCOBJ_HISTOGRAM					180
#define	IDI_RVCOBJ_HYPERSPECTRAL			181
#define	IDI_RVCOBJ_LEGEND						182
#define	IDI_RVCOBJ_METADATA					183
#define	IDI_RVCOBJ_DISP_LAYOUT				184
#define	IDI_RVCOBJ_TIEPOINT					185
#define	IDI_RVCOBJ_RASTER_GRAY				186
#define	IDI_RVCOBJ_RASTER_GREEN				187
#define	IDI_RVCOBJ_RASTER_RED				188
#define	IDI_RVCOBJ_REGION						189
#define	IDI_RVCOBJ_SMLSCRIPT					190
#define	IDI_RVCOBJ_STYLE						191
#define	IDI_RVCOBJ_DB_TABLE_STYLE			192
#define	IDI_RVCOBJ_TEXT						193
#define	IDI_RVCOBJ_RASTER_BLUE				194
#define	IDI_RVCOBJ_VECTOR						195
#define	IDI_RVCOBJ_TIN							196
#define	IDI_GRE_LAYER_SKETCH					197
#define	IDI_GRE_GROUP_3D						198
#define	IDI_ELEMENT_TRIANGLE_CYAN			199
#define	IDI_ELEMENT_LABEL_CYAN				200
#define	IDI_ELEMENT_LINE_CYAN				201
#define	IDI_ELEMENT_NODE_CYAN				202
#define	IDI_ELEMENT_POINT_CYAN				203
#define	IDI_ELEMENT_POLYGON_CYAN			204
#define	IDI_ELEMENT_EDGE_CYAN				205
#define	IDI_CHECKBOX_RED						206
#define	IDI_CHECKBOX_EMPTY					207
#define	IDI_CHECKBOX_BLACK					208
#define	IDI_EDIT_CIRCLESLASH_RED			209
#define	IDI_EDIT_CIRCLESLASH_DKGRAY		210
#define	IDI_RVCOBJ_RASTER_YELLOW			211
#define	IDI_RVCOBJ_RASTER_HUE				212
#define	IDI_RVCOBJ_RASTER_MAGENTA			213
#define	IDI_RVCOBJ_RASTER_SATURATION		214
#define	IDI_RVCOBJ_RASTER_CYAN				215
#define	IDI_BLANK								217
#define	IDI_CONTROL_STOP_CYAN				218
#define	IDI_CONTROL_FAST_REVERSE_CYAN		219
#define	IDI_CONTROL_PAUSE_CYAN				220
#define	IDI_CONTROL_PLAY_FORWARD_CYAN		221
#define	IDI_CONTROL_PLAY_REVERSE_CYAN		222
#define	IDI_CONTROL_SKIP_FORWARD_CYAN		223
#define	IDI_CONTROL_SKIP_REVERSE_CYAN		224
#define	IDI_CONTROL_FAST_FORWARD_CYAN		225
#define	IDI_EDIT_SELECT_RED_SLASH			226
#define	IDI_CHECKBOX_DKGRAY					227
#define	IDI_NEW_RECORD							228
#define	IDI_SELECT_MULTI_CYAN				229
#define	IDI_SELECT_ONE_CYAN					230
#define	IDI_SELECT_TOGGLE_CYAN				231
#define	IDI_SELECT_UNDO_CYAN					232
#define	IDI_VIEW_ACTIVE_ELEMENT				233
#define	IDI_VIEW_ALL_ELEMENTS				234
#define	IDI_VIEW_SELECTED_ELEMENTS			235
#define	IDI_CONTROL_SUBTRACT_CYAN			236
#define	IDI_CONTROL_ADD_CYAN					237
#define	IDI_CONTROL_REFRESH_CYAN			238
#define	IDI_CONTROL_SUBTRACT_ALL_CYAN		239
#define	IDI_CONTROL_ADD_ALL_CYAN			240
#define	IDI_NAVIGATE_GOTO						241
#define	IDI_FOLDER_NAVIGATE_OUT				242
#define	IDI_FOLDER_NEW							243
#define	IDI_CONTROL_MAGICWAND_CYAN			244
#define	IDI_DESKTOP_NETWORK					246
#define	IDI_DESKTOP_DRIVE_CDROM				247
#define	IDI_DESKTOP_DRIVE_FIXED				248
#define	IDI_DESKTOP_DRIVE_FLOPPY			249
#define	IDI_DESKTOP_DRIVE_NETWORK			250
#define	IDI_DESKTOP_DRIVE_REMOVABLE		251
#define	IDI_DESKTOP_FILE						252
#define	IDI_DESKTOP_FOLDER_CLOSED			253
#define	IDI_DESKTOP_FOLDER_OPEN				254
#define	IDI_DESKTOP_COMPUTER					255
#define	IDI_RVCOBJ_GENERIC					256
#define	IDI_RVCOBJ_FILE						257
#define	IDI_STYLE_VIEW_LIST					258
#define	IDI_STYLE_PATTERN_EDIT				259
#define	IDI_STYLE_PATTERN_EDITSET			260
#define	IDI_STYLE_PATTERN_NEW				261
#define	IDI_STYLE_STYLE_COPY					262
#define	IDI_STYLE_STYLE_NEW					263
#define	IDI_STYLE_VIEW_ICONS					264
#define	IDI_STYLE_PATTERN_COPY				265
#define	IDI_MATH_STDDEV						267
#define	IDI_MATH_MAX							268
#define	IDI_MATH_MEAN							269
#define	IDI_MATH_MIN							270
#define	IDI_MATH_N								271
#define	IDI_MATH_SIGMA							272
#define	IDI_BULLET_RED							273
#define	IDI_BULLET_GRAY						274
#define	IDI_EDIT_CONTROLS						277
#define	IDI_CREATE_OBJECT						278
#define	IDI_CREATE_FILE_MI					279
#define	IDI_CREATE_FOLDER						280
#define	IDI_CREATE_FOLDER_MI					281
#define	IDI_CREATE_FILE						282
#define	IDI_EDIT_RENAME						284
#define	IDI_HELP									285
#define	IDI_SML_SYNTAX							287
#define	IDI_EDIT_CUT							289
#define	IDI_EDIT_COPY							290
#define	IDI_EDIT_PASTE							291
#define	IDI_LOGO_MI								302
#define	IDI_FILE_BROWSE						303
#define	IDI_LAYER_UP_YELLOW					304
#define	IDI_LAYER_ADD_RED						305
#define	IDI_LAYER_ADD_YELLOW					306
#define	IDI_LAYER_BOTTOM_RED					307
#define	IDI_LAYER_BOTTOM_YELLOW				308
#define	IDI_LAYER_DELETE_ALL_YELLOW		309
#define	IDI_LAYER_DELETE_RED					310
#define	IDI_LAYER_DELETE_YELLOW				311
#define	IDI_LAYER_DOWN_RED					312
#define	IDI_LAYER_DOWN_YELLOW				313
#define	IDI_LAYER_PLAY_RED					314
#define	IDI_CHECKMARK_BLACK					315
#define	IDI_LAYER_TOP_RED						317
#define	IDI_LAYER_TOP_YELLOW					318
#define	IDI_LAYER_UP_RED						319
#define	IDI_LAYER_TOOL_YELLOW				320
#define	IDI_MEASURE_PROFILE					321
#define	IDI_MEASURE_HISTOGRAM				322
#define	IDI_MEASURE_CROSS_SECTION			323
#define	IDI_MESSAGES_ERROR					324
#define	IDI_MESSAGES_EXCLAMATION			325
#define	IDI_MESSAGES_INFORMATION			326
#define	IDI_MESSAGES_QUESTION				327
#define	IDI_MESSAGES_WORK						328
#define	IDI_EDIT_PENCIL						329
#define	IDI_ADD_BLOCK_RED						331
#define	IDI_ADD_CIRCLE_RED					332
#define	IDI_ADD_CIRCULAR_ARC_RED			333
#define	IDI_ADD_CIRCULAR_ARC_CHORD_RED	334
#define	IDI_ADD_CIRCULAR_ARC_WEDGE_RED	335
#define	IDI_ADD_ELLIPSE_RED					336
#define	IDI_ADD_ELLIPTICAL_ARC_RED			337
#define	IDI_ADD_ELLIPTICAL_ARC_CHORD_RED	338
#define	IDI_ADD_ELLIPTICAL_ARC_WEDGE_RED	339
#define	IDI_ADD_CROSSING_LINE_RED			340
#define	IDI_ADD_DASHED_LINE_RED				341
#define	IDI_ADD_MESH_RED						342
#define	IDI_ADD_NODE_RED						343
#define	IDI_ADD_POINT_RED						344
#define	IDI_ADD_POLYLINE_RED					345
#define	IDI_ADD_POLYGON_RED					346
#define	IDI_ADD_RECTANGLE_RED				347
#define	IDI_ADD_SOLID_LINE_RED				348
#define	IDI_ADD_TEXT_RED						349
#define	IDI_ADD_VERTEX_RED					350
#define	IDI_LINE_HORIZONTAL_RED				351
#define	IDI_LINE_WAVY_RED						352
#define	IDI_LINE_ZIGZAG_RED					353
#define	IDI_SML_ASSEMBLY						354
#define	IDI_SML_BREAK_AND_PC					355
#define	IDI_SML_BREAKPOINT					356
#define	IDI_SML_PC								357
#define	IDI_SML_TIMINGS						358
#define	IDI_SML_STEP							359
#define	IDI_LIST_COLLAPSE						360
#define	IDI_LIST_EXPAND						361
#define	IDI_EDIT_FIND_CYAN					362
#define	IDI_SELECT_INVERT_CYAN				363
#define	IDI_SELECT_ALL_CYAN					364
#define	IDI_SELECT_CLEAR_CYAN				365
#define	IDI_SELECT_PLUS_CYAN					366
#define	IDI_SELECT_MINUS_CYAN				367
#define	IDI_GEOREF_ADD_HARD_EDGE			368
#define	IDI_GEOREF_DEL_HARD_EDGES			369
#define	IDI_GEOREF_DEL_TRIANGLES			370
#define	IDI_GEOREF_DEL_EDGES					371
#define	IDI_GEOREF_FIND						372
#define	IDI_GEOREF_RECOVER_DELETED			373
#define	IDI_GEOREF_CLIP_REGION				374
#define	IDI_GEOREF_DEL_REGION				375
#define	IDI_ARROW_DOWN_BLACK					376
#define	IDI_ARROW_LEFT_BLACK					377
#define	IDI_ARROW_RIGHT_BLACK				378
#define	IDI_ARROW_UP_BLACK					379
#define	IDI_GEOREF_ADD_CONTROL_PT			380
#define	IDI_ADD_REGION_RED					381
#define	IDI_COMBINE_MERGE_CLASSES			382
#define	IDI_CONNECTED_4						383
#define	IDI_CONNECTED_8						384
#define	IDI_ADVISOR_LIGHT_BULB				385
#define	IDI_RVCOBJ_SHAPE						386
#define	IDI_TITLE_TNTSERVER					387
#define	IDI_TITLE_TNTMIPS						388
#define	IDI_RVCOBJ_ALLTYPES					389
#define	IDI_MESSAGES_PAUSE					390
#define	IDI_MESSAGES_PLAY						391
#define	IDI_MESSAGES_STOP						392
#define	IDI_RVCOBJ_ICM							393
#define	IDI_CHECK_GREY							394
#define	IDI_CHECK_BLACK						395
#define	IDI_PADLOCK_OPEN						396
#define	IDI_PADLOCK_CLOSED					397
#define	IDI_EDIT_ACL							398
#define	IDI_RVCOBJ_DBFORM						399
#define	IDI_RVCOBJ_DB_TABLE_LINKED_MISSING	400
#define	IDI_GRE_PROJECT_SETTINGS			401
#define	IDI_EDIT_LAYER							402
#define	IDI_CREATE_OBJECT_LIGHTNING		403
#define	IDI_EDIT_OBJECT_CAD					404
#define	IDI_EDIT_OBJECT_RASTER				405
#define	IDI_EDIT_OBJECT_SHAPE				406
#define	IDI_EDIT_OBJECT_TIN					407
#define	IDI_EDIT_OBJECT_VECTOR				408
#define	IDI_BULLET_YELLOW						409
#define	IDI_BULLET_GREEN						410
#define	IDI_ELEMENT_COPY						411
#define	IDI_ELEMENT_EDIT						412
#define	IDI_ELEMENT_DELETE					413
#define	IDI_MORPHOLOGY_SHORT_LINE			414
#define	IDI_MORPHOLOGY_DIAGONAL				415
#define	IDI_MORPHOLOGY_LONG_LINE			416
#define	IDI_MORPHOLOGY_TEE					417
#define	IDI_EXECUTE								418
#define	IDI_GROUP_CONTROLS					419
#define	IDI_LAYER_CONTROLS					420
#define	IDI_RVCOBJ_MAP							421
#define	IDI_WATERSHED_COMPUTE_FP_B			422
#define	IDI_WATERSHED_DEPRESSION			423
#define	IDI_WATERSHED_FILL_DEPR				424
#define	IDI_WATERSHED_FILL_DEPR_BY_QUERY	425
#define	IDI_WATERSHED_FILL_DOUBLE			426
#define	IDI_WATERSHED_FILL_LOWER			427
#define	IDI_WATERSHED_FILL_UPPER			428
#define	IDI_WATERSHED_FIND_DEPR				429
#define	IDI_WATERSHED_HISTOGRAM				430
#define	IDI_WATERSHED_MOVE_THRU_LOW		431
#define	IDI_WATERSHED_MOVE_THRU_UP			432
#define	IDI_WATERSHED_NEXT_DEPR				433
#define	IDI_WATERSHED_NEXT_DOUBLE			434
#define	IDI_WATERSHED_NEXT_LOW_POURS		435
#define	IDI_WATERSHED_NEXT_UP_POURS		436
#define	IDI_WATERSHED_NEXT_WTR				437
#define	IDI_WATERSHED_ONE_OR_MORE			438
#define	IDI_WATERSHED_POUR_POINT			439
#define	IDI_WATERSHED_PREV_DEPR				440
#define	IDI_WATERSHED_PREV_DOUBLE			441
#define	IDI_WATERSHED_PREV_LOW_POURS		442
#define	IDI_WATERSHED_PREV_UP_POURS		443
#define	IDI_WATERSHED_PREV_WTR				444
#define	IDI_WATERSHED_REMOVE_NOISE			445
#define	IDI_WATERSHED_SELECT_WTR			446
#define	IDI_WATERSHED_SET_TO_DEFAULT		447
#define	IDI_WATERSHED_SHOW_BASIN			448
#define	IDI_WATERSHED_SHOW_FP				449
#define	IDI_WATERSHED_SHOW_RIDGE			450
#define	IDI_WATERSHED_SHOW_WTR				451
#define	IDI_GRIDTOOL_PARALLEL				452
#define	IDI_GRIDTOOL_TRIANGLE				453
#define	IDI_GRIDTOOL_SQUARE					454
#define	IDI_GRIDTOOL_RECTANGLE				455
#define	IDI_GRIDTOOL_HEXAGON					456
#define	IDI_GRIDTOOL_ORIENTATION			457
#define	IDI_GRIDTOOL_REGULAR					458
#define	IDI_GRIDTOOL_RANDOM_CLUSTER		459
#define	IDI_GRIDTOOL_SYSTEMATIC_UNALIGNED	460
#define	IDI_GRIDTOOL_RANDOM_RECTANGLE		461
#define	IDI_REORIENT_ROTATE_ANTICLOCKWISE		462
#define	IDI_REORIENT_ROTATE_CLOCKWISE		463
#define	IDI_VIEW_GLASSES_CYAN				464
#define	IDI_VIEW_GLASSES_BLACK				465
#define	IDI_HYPER_NAVIGATE_FORWARD			466
#define	IDI_SNAPSHOT							468
#define	IDI_HELP2								469
#define	IDI_HELP3								470
#define	IDI_SML_INSERT							471
#define	IDI_SML_INSERT2						472
#define	IDI_RECORD_MOVIE						473
#define	IDI_VIEW_TOOL_RECENTER				474
#define	IDI_STANDARD_EXTENTS					475
#define	IDI_ZOOM_TO_LOCATION					476
#define	IDI_STANDARD_GOTO_LINE				477
#define	IDI_TEXT_BOLD							478
#define	IDI_TEXT_ITALICS						479
#define	IDI_TEXT_UNDERLINE					480
#define	IDI_TEXT_ENHANCED						481
#define	IDI_TEXT_SHADOW						482
#define	IDI_TEXT_OUTLINE						483
#define	IDI_TEXT_FORMAT						484
#define	IDI_TEXT_LEFT_JUSTIFY				485
#define	IDI_TEXT_RIGHT_JUSTIFY				486
#define	IDI_TEXT_CENTER_JUSTIFY				487
#define	IDI_TEXT_FULL_JUSTIFY				488
#define	IDI_CONTACT_SUPPORT					489
#define	IDI_GOOGLE_EARTH						490
#define	IDI_LOCATOR								491
#define	IDI_REPAIR								493
#define	IDI_VALUERANGE							495
#define	IDI_PAINT_BUCKET						496
#define	IDI_REFERENCE_BOOK					497
#define	IDI_ADD_GROUP_RED						498
#define	IDI_VIEW_PREVIOUS_CYAN				499
#define	IDI_CONTROL_ADD_RGB					500
#define	IDI_VIEW_WHITE_TRANSPARENT			501
#define	IDI_VIEW_BLACK_TRANSPARENT			502
#define	IDI_EXECUTE_RESUME					503
#define	IDI_VIEW_GEOLOCK						504
#define	IDI_VIEW_STEREO						505
#define	IDI_ZOOM_FULL_EXTENTS				506
#define	IDI_ZOOM_MAX_DETAIL					507
#define	IDI_ZOOM_TO_GROUP						508
#define	IDI_ZOOM_TO_LAYER						509
#define	IDI_SELECT_PREVIOUS_RED				510
#define	IDI_SELECT_NEXT_RED					511
#define	IDI_EDIT_OBJECT_CAD_LARGE			512
#define	IDI_EDIT_OBJECT_TIN_LARGE			513
#define	IDI_EDIT_OBJECT_VECTOR_LARGE		514
#define	IDI_ADD_REGULAR_POLYGON_RED		515
#define	IDI_EDIT_CAD_BLOCK					516
#define	IDI_ASSIGN_Z_VALUES					517
#define	IDI_ASSIGN_CONTOUR_LABELS			518
#define	IDI_ADD_LINE_CONNECT_POINTS		519
#define	IDI_OPERATION_COGO					520
#define	IDI_OPERATION_INTERACTIVE_LINE_FOLLOWING	521
#define	IDI_FILTER_DISOLVE_POLYGON			522
#define	IDI_FILTER_REMOVE_BUBBLES			523
#define	IDI_FILTER_REMOVE_DANGLE			524
#define	IDI_FILTER_REMOVE_EXCESS_NODES	525
#define	IDI_FILTER_REMOVE_ISLANDS			526
#define	IDI_FILTER_REMOVE_SLIVER			527
#define	IDI_FILTER_SNAP						528
#define	IDI_FILTER_SPLINE						529
#define	IDI_FILTER_THIN_LINE					530
#define	IDI_MEASURE_PROTRACTOR				531
#define	IDI_GRE_COORDSOURCE_GPS				532
#define	IDI_GRE_COORDSOURCE_POINTER		533
#define	IDI_GRE_COORDSOURCE_USERENTERED	534
#define	IDI_GRE_COORDSOURCE_VIEWCENTER	535
#define	IDI_SDE_AUTO_GENERATE_LABEL		536
#define	IDI_SDE_BREAK_LINE					537
#define	IDI_SDE_CONVERT_NODE_TO_POINT		538
#define	IDI_SDE_ELEMENT_OFFSET				539
#define	IDI_SDE_ELEMENT_ORDER				540
#define	IDI_SDE_ELEMENT_STYLE				541
#define	IDI_SDE_JOIN_LINES					542
#define	IDI_SDE_LABEL_ATTRIBUTES			543
#define	IDI_SDE_MOVE_ELEMENT					544
#define	IDI_SDE_REVERSE_LINE_VERTICES		545
#define	IDI_SDE_SEPARATE_COMPLEX_ELEMENTS	546
#define	IDI_SDE_STRAIGHTEN_LINE				547
#define	IDI_SELECT_SINGLE_CYAN				548
#define	IDI_SELECT_BOX_CYAN					549
#define	IDI_SELECT_CIRCLE_CYAN				550
#define	IDI_SELECT_POLYGON_CYAN				551
#define	IDI_SELECT_REGION_CYAN				552
#define	IDI_ELEMENT_LINE_RED					553
#define	IDI_ELEMENT_POINT_RED				554
#define	IDI_ELEMENT_POLYGON_RED				555
#define	IDI_DRAW_CIRCLE_RED					556
#define	IDI_DRAW_CIRCLE_FILLED_RED			557
#define	IDI_DRAW_ELLIPSE_RED					558
#define	IDI_DRAW_ELLIPSE_FILLED_RED		559
#define	IDI_DRAW_LINE_RED						560
#define	IDI_DRAW_POLYGON_FILLED_RED		561
#define	IDI_DRAW_RECTANGLE_RED				562
#define	IDI_DRAW_RECTANGLE_FILLED_RED		563
#define	IDI_DRAW_REGULAR_POLYGON_RED		564
#define	IDI_DRAW_REGULAR_POLYGON_FILLED_RED	565
#define	IDI_DRAW_BRUSH_RED					566
#define	IDI_DRAW_GRID_RED						567
#define	IDI_FEATUREMAP_DEFINE_SAMPLES		568
#define	IDI_SDE_NUMERIC_EDIT					569
#define	IDI_CREATE_TABLE_LIGHTNING			570
#define	IDI_ELEMENT_GENERIC_RED				571
#define	IDI_LINK_SELECT_BLUE					572
#define	IDI_LINK_MENU_BLUE					573
#define	IDI_ADD_ELLIPSE_BLUE					574
#define	IDI_ADD_POLYGON_BLUE					575
#define	IDI_ADD_RECTANGLE_BLUE				576
#define	IDI_ELEMENT_POLYGON_BLUE			577
#define	IDI_ELEMENT_POINT_BLUE				578
#define	IDI_ELEMENT_LINE_BLUE				579
#define	IDI_ELEMENT_GENERIC_BLUE			580
#define	IDI_EDIT_ERASE							581
#define	IDI_VIEW_TOOL_PLACEMENT				582
#define	IDI_VIEW_TOOL_EXAMINERASTER		583
#define	IDI_SUBTRACT_POLYLINE_RED			584
#define	IDI_GRE_LAYER_WIREFRAME				585
#define	IDI_VIEW_3DVIEWPOINT					586
#define	IDI_SET_CONTOUR_ELEVATION			587
#define	IDI_SDE_HARDEN_AUTO_LABEL			588
#define	IDI_TOOL_SNAPGRID						589
#define	IDI_SDE_TRACE_REFERENCE_LINE		590
#define	IDI_SMALL_DELETE						591
#define	IDI_SMALL_BLANK						592
#define	IDI_SDE_ELEVATION_FROM_SURFACE	593
#define	IDI_INSERT_BEFORE						594
#define	IDI_SDE_FILL_FLOOD					595
#define	IDI_SDE_FILL_BOUNDARY				596
#define	IDI_SDE_FILL_SMART					597
#define	IDI_SDE_FILL_RASTER					598
#define	IDI_SDE_FILL_VISIBLE					599
#define	IDI_BRUSH_CIRCLE_16					600
#define	IDI_BRUSH_CIRCLE_14					601
#define	IDI_BRUSH_CIRCLE_12					602
#define	IDI_BRUSH_CIRCLE_10					603
#define	IDI_BRUSH_CIRCLE_8					604
#define	IDI_BRUSH_CIRCLE_6					605
#define	IDI_BRUSH_CIRCLE_4					606
#define	IDI_BRUSH_CIRCLE_2					607
#define	IDI_BRUSH_BOX_16						608
#define	IDI_BRUSH_BOX_14						609
#define	IDI_BRUSH_BOX_12						610
#define	IDI_BRUSH_BOX_10						611
#define	IDI_BRUSH_BOX_8						612
#define	IDI_BRUSH_BOX_6						613
#define	IDI_BRUSH_BOX_4						614
#define	IDI_BRUSH_BOX_2						615
#define	IDI_RASTER_DRAW_WEDGE				616
#define	IDI_RASTER_FILL_WEDGE				617
#define	IDI_RASTER_DRAW_CHORD				618
#define	IDI_RASTER_FILL_CHORD				619
#define	IDI_RASTER_DRAW_REGION				620
#define	IDI_RASTER_FILL_REGION				621
#define	IDI_RASTER_FILTER						622
#define	IDI_REVERT_RASTER						623
#define	IDI_RASTER_DRAW_ARC					624
#define	IDI_UP_RED								625
#define	IDI_DOWN_RED							626
#define	IDI_TOOLPOLYLINE_ADDSTART			627
#define	IDI_TOOLPOLYLINE_ADDEND				628
#define	IDI_TOOLPOLYLINE_DELETEVERTEX		629
#define	IDI_TOOLPOLYLINE_DRAGVERTEX		630
#define	IDI_TOOLPOLYLINE_INSERTVERTEX		631
#define	IDI_TOOLPOLYLINE_DRAW				632
#define	IDI_TOOLPOLYLINE_STRETCH			633
#define	IDI_TOOLPOLYLINE_CLOSE				634
#define	IDI_ADD_MULTIPOINT_RED				635
#define	IDI_HOT_KEY_INFO						636
#define	IDI_POINT_PROFILE_TOOL				637
#define	IDI_TOOLRECTANGLE_LOWERLEFT		638
#define	IDI_TOOLRECTANGLE_LOWERRIGHT		639
#define	IDI_TOOLRECTANGLE_UPPERLEFT		640
#define	IDI_TOOLRECTANGLE_UPPERRIGHT		641
#define	IDI_GOOGLE_CONTROLS					642
#define	IDI_TOOLPOLYLINE_MOVELINE			643
#define	IDI_CIRCLE_OPEN_SMALL				644
#define	IDI_CIRCLE_ON_BLACK_SMALL			645
#define	IDI_SMALL_BROWSE						646
#define	IDI_DBRECORD_ATTACHED				647
#define	IDI_DBRECORD_RELATED					648
#define	IDI_DBRECORD_ATTACHED_FIRST		649
#define	IDI_DBRECORD_ATTACHED_NEXT			650
#define	IDI_DBRECORD_ATTACHED_PREVIOUS	651
#define	IDI_DBRECORD_ATTACHED_LAST			652
#define	IDI_DBRECORD_ATTACHED_GOTO			653
#define	IDI_DBVIEW_SWITCH_TOSINGLE			654
#define	IDI_DBVIEW_SWITCH_TOMULTI			655
#define	IDI_ARROW_SMALL_DOWN					656
#define	IDI_ARROW_SMALL_LEFT					657
#define	IDI_ARROW_SMALL_RIGHT				658
#define	IDI_ARROW_SMALL_UP					659
#define	IDI_RVCOBJ_RASTER_MULTIBAND		660
#define	IDI_JOB_QUEUE							661
#define	IDI_JOB_SAVE							662
#define	IDI_SELECT_BANDS_RGB					663
#define	IDI_SQUARE_OPEN_SMALL				664
#define	IDI_SQUARE_ON_BLACK_SMALL			665
#define	IDI_ARROW_DOWN_CYAN					666
#define	IDI_ARROW_LEFT_CYAN					667
#define	IDI_ARROW_RIGHT_CYAN					668
#define	IDI_ARROW_UP_CYAN						669
#define	IDI_ARROW_UPDOWN_YELLOW				670
#define	IDI_TOOLRECTANGLE_ORIENT_HORIZONTAL_ANGLE_UP		671
#define	IDI_TOOLRECTANGLE_ORIENT_VERTICAL_ANGLE_RIGHT	672
#define	IDI_CONTROL_ADD_YELLOW				673
#define	IDI_CONTROL_ADD_ALL_RECURSIVE_CYAN	674
#define	IDI_EDIT_COPY_MAP						675
#define	IDI_EDIT_LINK_MAP						676
#define	IDI_EDIT_NAME							677
#define	IDI_EDIT_REPLICATE_MAP				678
#define	IDI_FILE_BREAK_LOCK					679
#define	IDI_FILE_INFO							680
#define	IDI_FILE_PACK							681
#define	IDI_BULLET_GREY						682
#define	IDI_FILETYPE_TILESET					683
#define	IDI_FILE_VALIDATE						684
#define	IDI_RVCOBJ_INTERNAL					685
#define	IDI_RVCOBJ_FILTER						686
#define	IDI_RVCOBJ_HYPERLINKS				687
#define	IDI_RVCOBJ_FREQPROCINFO				688
#define	IDI_RVCOBJ_SATELLITEINFO			689
#define	IDI_RVCOBJ_CAMERAINFO				690
#define	IDI_RVCOBJ_DISPPARM					691
#define	IDI_RVCOBJ_EDITPARM					692
#define	IDI_RVCOBJ_SPATIALTREE				693
#define	IDI_RVCOBJ_SPECTRAL					694
#define	IDI_BROWSER_CHROME					695
#define	IDI_BROWSER_FIREFOX					696
#define	IDI_BROWSER_OPERA						697
#define	IDI_BROWSER_SAFARI					698
#define	IDI_BROWSER_IEXPLORE					700
#define	IDI_BROWSER_WEBKIT					701
#define	IDI_BROWSER_SEAMONKEY				702
#define	IDI_PREFERENCES_GENERAL				703
#define	IDI_MATH_ADD							704
#define	IDI_MATH_SUBTRACT						705
#define	IDI_MATH_MULTIPLY						706
#define	IDI_MATH_DIVIDE						707
#define	IDI_MATH_POWER							708
#define	IDI_MATH_GROUP							709
#define	IDI_MATH_UNGROUP						710
#define	IDI_ARROW_VAR_5X3						711
#define	IDI_ARROW_VAR_7X4						712
#define	IDI_ARROW_VAR_9X5						713
#define	IDI_ARROW2_VAR_11X3					714
#define	IDI_ARROW2_VAR_15X4					715
#define	IDI_ARROW2_VAR_19X5					716
#define	IDI_ZOOM_CYAN							717
#define	IDI_RVCOBJ_LIDAR						718
#define	IDI_GRE_GROUP_PAIR_OVERLAPPED		719
#define	IDI_GEOREF_CP_FIND					720
#define	IDI_GEOREF_CP_AUTOCORRELATE_RED	721
#define	IDI_GEOREF_CP_ESTIMATE_RED			722
#define	IDI_GEOREF_CP_SNAP_TO_ELEMENT_RED	723
#define	IDI_GEOREF_CP_SNAP_TO_ENDPT_RED	724
#define	IDI_GEOREF_CP_SNAP_TO_VERTEX_RED	725
#define	IDI_GEOREF_CP_DFTZ_RED				726
#define	IDI_GEOREF_CP_AUTOCORRELATE_BLUE	727
#define	IDI_GEOREF_CP_ESTIMATE_BLUE		728
#define	IDI_GEOREF_CP_SNAP_TO_ELEMENT_BLUE	729
#define	IDI_GEOREF_CP_SNAP_TO_ENDPT_BLUE	730
#define	IDI_GEOREF_CP_SNAP_TO_VERTEX_BLUE	731
#define	IDI_APPLY_TO_BLUE						732
#define	IDI_APPLY_TO_RED						733
#define	IDI_REORIENT_FLIP_HORIZONTAL		734
#define	IDI_REORIENT_FLIP_VERTICAL			735
#define	IDI_GEOREF_GET_ELEVATION			736
#define	IDI_GEOREF_CP_SELECT					737
#define	IDI_GEOREF_TIEPOINT					738
#define	IDI_CROSSHAIR_RED						739
#define	IDI_GEOREF_CP_SNAP_TO_GRID_RED	740
#define	IDI_LAYER_BINGMAPS					741
#define	IDI_GEOREF_AUTO_REGISTER			742
#define	IDI_LINK_VAR_13X13					743
#define	IDI_PADLOCK_CLOSED_13X13			744
#define	IDI_ARROW_TOP_SIMPLE_RED			745
#define	IDI_ARROW_UP_SIMPLE_RED				746
#define	IDI_ARROW_DOWN_SIMPLE_RED			747
#define	IDI_ARROW_BOTTOM_SIMPLE_RED		748
#define	IDI_COLOR_DROPDOWN					749
#define	IDI_COLOR_DROPDOWN_OUTER			750
#define	IDI_COLOR_DROPDOWN_POINT			751
#define	IDI_COLOR_DROPDOWN_X					752
#define	IDI_COLOR_DROPDOWN_OUTER_X			753
#define	IDI_DRAW_LINE_THICKNESS_1			754
#define	IDI_DRAW_LINE_THICKNESS_2			755
#define	IDI_DRAW_LINE_THICKNESS_3			756
#define	IDI_DRAW_LINE_THICKNESS_4			757
#define	IDI_DRAW_LINE_THICKNESS_5			758
#define	IDI_TEXT_FONT							759
#define	IDI_PRINT								760
#define	IDI_PRINT_SNAPSHOT					761
#define	IDI_FILETYPE_TERRAINTILESET		762
#define	IDI_SET_ALL_LEVELS					763
#define	IDI_SET_SELECTED_LEVELS				764
#define	IDI_DELETE_FILE						765
#define	IDI_DELETE_TABLE						766
#define	IDI_DRAW_POINT_RED					767
#define	IDI_GEOREF_SELECT_HARD_EDGE		768
#define	IDI_FEATUREMAP_ROI					769
#define	IDI_FEATUREMAP_CATEGORIES			770
#define	IDI_FEATUREMAP_DRAW_PROTOTYPES	771
#define	IDI_FEATUREMAP_GROW_AND_MARK		772
#define	IDI_FEATUREMAP_MARK_FEATURES		773
#define	IDI_FEATUREMAP_DRAW_MARKED			774
#define	IDI_FEATUREMAP_PROTECT				775
#define	IDI_FEATUREMAP_ATTACH_VECTOR		776
#define	IDI_FEATUREMAP_CALIBRATE			777
#define	IDI_CIRCLE_SOLID_GREEN				778
#define	IDI_CLASSES_PROCESS					779
#define	IDI_SELECT_BY_QUERY_CYAN			780

#ifndef ICONIDTABLE

#define	ICONIDTABLE \
			enum ICONID

#define	ICONIDENTRY1(idiname,xgroup,xname,xsize) \
			ICONID_##idiname = IDI_##idiname,

#define	ICONIDENTRY2(idiname,xgroup1,xname1,xsize1,xgroup2,xname2,xsize2) \
			ICONID_##idiname = IDI_##idiname,

#define	ICONIDENTRY3(idiname,xgroup1,xname1,xsize1,xgroup2,xname2,xsize2,xgroup3,xname3,xsize3) \
			ICONID_##idiname = IDI_##idiname,

#define	ICONIDENTRYLAST \
			ICONID_LAST

#define	ICONID__NONE	static_cast<ICONID>(0)

#endif

//! Icon ID enumeration table, also used to generate translation table for X implementation.
//!

ICONIDTABLE {
	ICONIDENTRY1(ADD_BLOCK_RED,"TNTedit","add_block",16)
	ICONIDENTRY1(ADD_CIRCLE_RED,"TNTedit","add_circle",16)
	ICONIDENTRY1(ADD_CIRCULAR_ARC_CHORD_RED,"TNTedit","add_arc_chord",16)
	ICONIDENTRY1(ADD_CIRCULAR_ARC_RED,"TNTedit","add_arc",16)
	ICONIDENTRY1(ADD_CIRCULAR_ARC_WEDGE_RED,"TNTedit","add_arc_wedge",16)
	ICONIDENTRY1(ADD_CROSSING_LINE_RED,"TNTedit","add_cross_line",16)
	ICONIDENTRY1(ADD_DASHED_LINE_RED,"TNTedit","add_dashed_line",16)
	ICONIDENTRY1(ADD_ELLIPSE_RED,"TNTedit","add_ellipse",16)
	ICONIDENTRY1(ADD_ELLIPSE_BLUE,"TNTedit","add_ellips_blue",16)
	ICONIDENTRY1(ADD_ELLIPTICAL_ARC_CHORD_RED,"TNTedit","add_elip_chord",16)
	ICONIDENTRY1(ADD_ELLIPTICAL_ARC_RED,"TNTedit","add_elip_arc",16)
	ICONIDENTRY1(ADD_ELLIPTICAL_ARC_WEDGE_RED,"TNTedit","add_elip_wedge",16)
	ICONIDENTRY1(ADD_GROUP_RED,"standard","add_group",16)
	ICONIDENTRY1(ADD_LINE_CONNECT_POINTS,"TNTedit","gps_connect",16)
	ICONIDENTRY1(ADD_MESH_RED,"TNTedit","add_mesh",16)
	ICONIDENTRY1(ADD_MULTIPOINT_RED,"TNTedit","add_multi_point",16)
	ICONIDENTRY1(ADD_NODE_RED,"TNTedit","add_node",16)
	ICONIDENTRY1(ADD_POINT_RED,"TNTedit","add_point",16)
	ICONIDENTRY1(ADD_POLYGON_RED,"TNTedit","add_polygon",16)
	ICONIDENTRY1(ADD_POLYGON_BLUE,"TNTedit","add_poly_blue",16)
	ICONIDENTRY1(ADD_POLYLINE_RED,"TNTedit","add_line",16)
	ICONIDENTRY1(ADD_RECTANGLE_RED,"TNTedit","add_rectangle",16)
	ICONIDENTRY1(ADD_RECTANGLE_BLUE,"TNTedit","add_rect_blue",16)
	ICONIDENTRY1(ADD_REGION_RED,"TNTedit","add_region",16)
	ICONIDENTRY1(ADD_REGULAR_POLYGON_RED,"TNTedit","add_reg_polygon",16)
	ICONIDENTRY1(ADD_SOLID_LINE_RED,"TNTedit","add_solid_line",16)
	ICONIDENTRY1(ADD_TEXT_RED,"TNTedit","add_label",16)
	ICONIDENTRY1(ADD_VERTEX_RED,"TNTedit","add_vertex",16)
	ICONIDENTRY1(ADVISOR_LIGHT_BULB,"advisor","light_bulb",48)
	ICONIDENTRY1(APPLY_TO_BLUE,"standard","apply_to",16)
	ICONIDENTRY1(APPLY_TO_RED,"standard","applyto_red",16)
	ICONIDENTRY1(ARROW_BOTTOM_SIMPLE_RED,"arrows","bot_simple_red",16)
	ICONIDENTRY1(ARROW_DOWN_BLACK,"arrows","down_blk",16)
	ICONIDENTRY1(ARROW_DOWN_CYAN,"arrows","down",16)
	ICONIDENTRY1(ARROW_DOWN_SIMPLE_RED,"arrows","dn_simple_red",16)
	ICONIDENTRY1(ARROW_LEFT_BLACK,"arrows","left_blk",16)
	ICONIDENTRY1(ARROW_LEFT_CYAN,"arrows","left",16)
	ICONIDENTRY1(ARROW_RIGHT_BLACK,"arrows","right_blk",16)
	ICONIDENTRY1(ARROW_RIGHT_CYAN,"arrows","right",16)
	ICONIDENTRY1(ARROW_SMALL_DOWN,"small","arrow_down",11)
	ICONIDENTRY1(ARROW_SMALL_LEFT,"small","arrow_left",11)
	ICONIDENTRY1(ARROW_SMALL_RIGHT,"small","arrow_right",11)
	ICONIDENTRY1(ARROW_SMALL_UP,"small","arrow_up",11)
	ICONIDENTRY1(ARROW_TOP_SIMPLE_RED,"arrows","top_simple_red",16)
	ICONIDENTRY1(ARROW_UP_BLACK,"arrows","up_blk",16)
	ICONIDENTRY1(ARROW_UP_CYAN,"arrows","up",16)
	ICONIDENTRY1(ARROW_UP_SIMPLE_RED,"arrows","up_simple_red",16)
	ICONIDENTRY1(ARROW_UPDOWN_YELLOW,"RVCobjects","sortby",16)
	ICONIDENTRY1(ARROW_VAR_5X3,"thin","arw5by3var",5)
	ICONIDENTRY1(ARROW_VAR_7X4,"thin","arw7by4var",7)
	ICONIDENTRY1(ARROW_VAR_9X5,"thin","arw9by5var",9)
	ICONIDENTRY1(ARROW2_VAR_11X3,"thin","arw5by3x2var",11)
	ICONIDENTRY1(ARROW2_VAR_15X4,"thin","arw7by4x2var",15)
	ICONIDENTRY1(ARROW2_VAR_19X5,"thin","arw9by5x2var",19)
	ICONIDENTRY1(ASSIGN_CONTOUR_LABELS,"TNTedit","label_contours",16)
	ICONIDENTRY1(ASSIGN_Z_VALUES,"standard","z_values",16)
	ICONIDENTRY1(BLANK,"standard","blank",16)
	ICONIDENTRY1(BROWSER_CHROME,"standard","chrome",16)
	ICONIDENTRY1(BROWSER_FIREFOX,"standard","firefox",16)
	ICONIDENTRY1(BROWSER_IEXPLORE,"standard","iexplore",16)
	ICONIDENTRY1(BROWSER_OPERA,"standard","opera",16)
	ICONIDENTRY1(BROWSER_SAFARI,"standard","safari",16)
	ICONIDENTRY1(BROWSER_SEAMONKEY,"standard","seamonkey",16)
	ICONIDENTRY1(BROWSER_WEBKIT,"standard","webkit",16)
	ICONIDENTRY1(BRUSH_CIRCLE_16,"EditIcons","circle16",32)
	ICONIDENTRY1(BRUSH_CIRCLE_14,"EditIcons","circle14",32)
	ICONIDENTRY1(BRUSH_CIRCLE_12,"EditIcons","circle12",32)
	ICONIDENTRY1(BRUSH_CIRCLE_10,"EditIcons","circle10",32)
	ICONIDENTRY1(BRUSH_CIRCLE_8,"EditIcons","circle8",32)
	ICONIDENTRY1(BRUSH_CIRCLE_6,"EditIcons","circle6",32)
	ICONIDENTRY1(BRUSH_CIRCLE_4,"EditIcons","circle4",32)
	ICONIDENTRY1(BRUSH_CIRCLE_2,"EditIcons","circle2",32)
	ICONIDENTRY1(BRUSH_BOX_16,"EditIcons","box16",32)
	ICONIDENTRY1(BRUSH_BOX_14,"EditIcons","box14",32)
	ICONIDENTRY1(BRUSH_BOX_12,"EditIcons","box12",32)
	ICONIDENTRY1(BRUSH_BOX_10,"EditIcons","box10",32)
	ICONIDENTRY1(BRUSH_BOX_8,"EditIcons","box8",32)
	ICONIDENTRY1(BRUSH_BOX_6,"EditIcons","box6",32)
	ICONIDENTRY1(BRUSH_BOX_4,"EditIcons","box4",32)
	ICONIDENTRY1(BRUSH_BOX_2,"EditIcons","box2",32)
	ICONIDENTRY1(BULLET_GRAY,"small","redball",16)
	ICONIDENTRY1(BULLET_GREY,"small","grayball",16)
	ICONIDENTRY1(BULLET_GREEN,"small","greenball",16)
	ICONIDENTRY1(BULLET_RED,"small","redball",16)
	ICONIDENTRY1(BULLET_YELLOW,"small","yellowball",16)
	ICONIDENTRY1(CHECK_BLACK,"standard","check_black",16)
	ICONIDENTRY1(CHECK_GREY,"standard","check_grey",16)
	ICONIDENTRY1(CHECKBOX_BLACK,"standard","checkbox_on",16)
	ICONIDENTRY1(CHECKBOX_DKGRAY,"standard","checkbox_gray",16)
	ICONIDENTRY1(CHECKBOX_EMPTY,"standard","checkbox_off",16)
	ICONIDENTRY1(CHECKBOX_RED,"standard","checked",16)
	ICONIDENTRY1(CIRCLE_OPEN_SMALL,"small","circle_open",11)
	ICONIDENTRY1(CIRCLE_ON_BLACK_SMALL,"small","circle_on_black",11)
	ICONIDENTRY1(CIRCLE_SOLID_GREEN,"standard","go",16)
	ICONIDENTRY1(CLASSES_PROCESS,"featmap","auto_class",16)
	ICONIDENTRY1(COLOR_DROPDOWN,"standard","clr_dropdown",16)
	ICONIDENTRY1(COLOR_DROPDOWN_X,"standard","clr_dropdownx",16)
	ICONIDENTRY1(COLOR_DROPDOWN_OUTER,"standard","clr_outer_drop",16)
	ICONIDENTRY1(COLOR_DROPDOWN_OUTER_X,"standard","clr_outer_dropx",16)
	ICONIDENTRY1(COLOR_DROPDOWN_POINT,"standard","clr_pt_drop",16)
	ICONIDENTRY1(COMBINE_AREA_INTERSECT,"standard","intersection",16)
	ICONIDENTRY1(COMBINE_AREA_SUBTRACT,"standard","subtract",16)
	ICONIDENTRY1(COMBINE_AREA_UNION,"standard","union",16)
	ICONIDENTRY1(COMBINE_AREA_XOR,"standard","exclusive_or",16)
	ICONIDENTRY1(COMBINE_MERGE_CLASSES,"featmap","merge_classes",16)
	ICONIDENTRY1(CONNECTED_4,"morphology","cross",16)
	ICONIDENTRY1(CONNECTED_8,"morphology","square",16)
	ICONIDENTRY1(CONTACT_SUPPORT,"processes32","letter",32)
	ICONIDENTRY1(CONTROL_ADD_ALL_CYAN,"standard","add_all",16)
	ICONIDENTRY1(CONTROL_ADD_ALL_RECURSIVE_CYAN,"standard","add_all_recurse",16)
	ICONIDENTRY1(CONTROL_ADD_CYAN,"standard","add_sel",16)
	ICONIDENTRY1(CONTROL_ADD_YELLOW,"standard","add_yellow",16)
	ICONIDENTRY1(CONTROL_ADD_RGB,"standard","ctrl_add_rgb",16)
	ICONIDENTRY1(CONTROL_FAST_FORWARD_CYAN,"standard","play_fast_fwd",16)
	ICONIDENTRY1(CONTROL_FAST_REVERSE_CYAN,"standard","play_fast_rev",16)
	ICONIDENTRY1(CONTROL_MAGICWAND_CYAN,"standard","mwand",16)
	ICONIDENTRY1(CONTROL_PAUSE_CYAN,"standard","pause",16)
	ICONIDENTRY1(CONTROL_PLAY_FORWARD_CYAN,"standard","play",16)
	ICONIDENTRY1(CONTROL_PLAY_REVERSE_CYAN,"standard","play_reverse",16)
	ICONIDENTRY1(CONTROL_REFRESH_CYAN,"standard","refresh",16)
	ICONIDENTRY1(CONTROL_SKIP_FORWARD_CYAN,"standard","skip",16)
	ICONIDENTRY1(CONTROL_SKIP_REVERSE_CYAN,"standard","skip_reverse",16)
	ICONIDENTRY1(CONTROL_STOP_CYAN,"standard","stop",16)
	ICONIDENTRY1(CONTROL_SUBTRACT_ALL_CYAN,"standard","remove_all",16)
	ICONIDENTRY1(CONTROL_SUBTRACT_CYAN,"standard","remove_sel",16)
	ICONIDENTRY1(CREATE_FILE,"standard","create_file",16)
	ICONIDENTRY1(CREATE_FILE_MI,"RVCobjects","create_rvc_file",16)
	ICONIDENTRY1(CREATE_FOLDER,"RVCobjects","create_object",16)
	ICONIDENTRY1(CREATE_FOLDER_MI,"RVCobjects","create_rvc_fldr",16)
	ICONIDENTRY1(CREATE_OBJECT,"RVCobjects","create_object",16)
	ICONIDENTRY1(CREATE_OBJECT_LIGHTNING,"RVCobjects","create",16)
	ICONIDENTRY1(CREATE_TABLE_LIGHTNING,"RVCobjects","create_table",16)
	ICONIDENTRY1(CROSSHAIR_RED,"standard","point_select",16)
	ICONIDENTRY1(DBRECORD_ATTACHED,"standard","dbrec_attached",16)
	ICONIDENTRY1(DBRECORD_ATTACHED_FIRST,"standard","dbrec_att_first",16)
	ICONIDENTRY1(DBRECORD_ATTACHED_GOTO,"standard","dbrec_att_goto",16)
	ICONIDENTRY1(DBRECORD_ATTACHED_LAST,"standard","dbrec_att_last",16)
	ICONIDENTRY1(DBRECORD_ATTACHED_NEXT,"standard","dbrec_att_next",16)
	ICONIDENTRY1(DBRECORD_ATTACHED_PREVIOUS,"standard","dbrec_att_prev",16)
	ICONIDENTRY1(DBRECORD_RELATED,"standard","dbrec_related",16)
	ICONIDENTRY1(DBVIEW_SWITCH_TOMULTI,"standard","dbview_swto_mul",16)
	ICONIDENTRY1(DBVIEW_SWITCH_TOSINGLE,"standard","dbview_swto_sgl",16)
	ICONIDENTRY1(DELETE_FILE,"standard","delete_file",16)
	ICONIDENTRY1(DELETE_TABLE,"standard","delete_table",16)
	ICONIDENTRY1(DESKTOP_COMPUTER,"Desktop16","computer",16)
	ICONIDENTRY1(DESKTOP_DRIVE_CDROM,"Desktop16","drive_cdrom",16)
	ICONIDENTRY1(DESKTOP_DRIVE_FIXED,"Desktop16","drive_fixed",16)
	ICONIDENTRY1(DESKTOP_DRIVE_FLOPPY,"Desktop16","drive_floppy",16)
	ICONIDENTRY1(DESKTOP_DRIVE_NETWORK,"Desktop16","drive_network",16)
	ICONIDENTRY1(DESKTOP_DRIVE_REMOVABLE,"Desktop16","drive_removable",16)
	ICONIDENTRY1(DESKTOP_FILE,"Desktop16","file",16)
	ICONIDENTRY1(DESKTOP_FOLDER_CLOSED,"Desktop16","folder_closed",16)
	ICONIDENTRY1(DESKTOP_FOLDER_OPEN,"Desktop16","folder_open",16)
	ICONIDENTRY1(DESKTOP_NETWORK,"Desktop16","network",16)
	ICONIDENTRY1(DOWN_RED,"small","down_red",16)
	ICONIDENTRY1(DRAW_BRUSH_RED,"standard","brush",16)
	ICONIDENTRY1(DRAW_CIRCLE_RED,"draw","circle",16)
	ICONIDENTRY1(DRAW_CIRCLE_FILLED_RED,"draw","circle_fill",16)
	ICONIDENTRY1(DRAW_ELLIPSE_RED,"draw","ellipse",16)
	ICONIDENTRY1(DRAW_ELLIPSE_FILLED_RED,"draw","ellipse_fill",16)
	ICONIDENTRY1(DRAW_GRID_RED,"standard","grid",16)
	ICONIDENTRY1(DRAW_LINE_RED,"draw","line",16)
	ICONIDENTRY1(DRAW_LINE_THICKNESS_1,"draw","line_1",16)
	ICONIDENTRY1(DRAW_LINE_THICKNESS_2,"draw","line_2",16)
	ICONIDENTRY1(DRAW_LINE_THICKNESS_3,"draw","line_3",16)
	ICONIDENTRY1(DRAW_LINE_THICKNESS_4,"draw","line_4",16)
	ICONIDENTRY1(DRAW_LINE_THICKNESS_5,"draw","line_5",16)
	ICONIDENTRY1(DRAW_POINT_RED,"draw","point",16)
	ICONIDENTRY1(DRAW_POLYGON_FILLED_RED,"draw","polygon",16)
	ICONIDENTRY1(DRAW_RECTANGLE_RED,"draw","rectangle",16)
	ICONIDENTRY1(DRAW_RECTANGLE_FILLED_RED,"draw","rectangle_fill",16)
	ICONIDENTRY1(DRAW_REGULAR_POLYGON_RED,"draw","reg_poly_line",16)
	ICONIDENTRY1(DRAW_REGULAR_POLYGON_FILLED_RED,"draw","reg_poly_fill",16)
	ICONIDENTRY1(EDIT_ACL,"standard","edit_acl",16)
	ICONIDENTRY1(EDIT_APPLY_RED,"standard","apply",16)
	ICONIDENTRY1(EDIT_CAD_BLOCK,"standard","edit_block",16)
	ICONIDENTRY1(EDIT_CIRCLESLASH_DKGRAY,"","",16)
	ICONIDENTRY1(EDIT_CIRCLESLASH_RED,"standard","hide",16)
	ICONIDENTRY1(EDIT_CONTROLS,"standard","layer_controls",16)
	ICONIDENTRY1(EDIT_COPY,"standard","copy_gen",16)
	ICONIDENTRY1(EDIT_COPY_MAP,"standard","copy_map",16)
	ICONIDENTRY1(EDIT_CUT,"standard","cut",16)
	ICONIDENTRY1(EDIT_DELETE_RED,"standard","delete",16)
	ICONIDENTRY1(EDIT_ERASE,"draw","eraser",16)
	ICONIDENTRY1(EDIT_FIND_CYAN,"standard","find",16)
	ICONIDENTRY1(EDIT_LAYER,"standard","edit_layer",16)
	ICONIDENTRY1(EDIT_LINK_MAP,"standard","link_to",16)
	ICONIDENTRY1(EDIT_NAME,"standard","edit_name",16)
	ICONIDENTRY1(EDIT_OBJECT_CAD,"RVCobjects","edit_cad",16)
	ICONIDENTRY1(EDIT_OBJECT_CAD_LARGE,"EditIcons","edit_cad",32)
	ICONIDENTRY1(EDIT_OBJECT_RASTER,"RVCobjects","edit_raster",16)
	ICONIDENTRY1(EDIT_OBJECT_SHAPE,"RVCobjects","edit_shape",16)
	ICONIDENTRY1(EDIT_OBJECT_TIN,"RVCobjects","edit_tin",16)
	ICONIDENTRY1(EDIT_OBJECT_TIN_LARGE,"EditIcons","edit_tin",32)
	ICONIDENTRY1(EDIT_OBJECT_VECTOR,"RVCobjects","edit_vector",16)
	ICONIDENTRY1(EDIT_OBJECT_VECTOR_LARGE,"EditIcons","edit_vector",32)
	ICONIDENTRY1(EDIT_PASTE,"standard","paste_gen",16)
	ICONIDENTRY1(EDIT_PENCIL,"featmap","prototypes",16)
	ICONIDENTRY1(EDIT_REDO_RED,"standard","redo",16)
	ICONIDENTRY1(EDIT_RENAME,"standard","rename_gen",16)
	ICONIDENTRY1(EDIT_REPLICATE_MAP,"standard","multi_copy",16)
	ICONIDENTRY1(EDIT_SELECT_RED,"standard","select",16)
	ICONIDENTRY1(EDIT_SELECT_RED_SLASH,"standard","select_redslash",16)
	ICONIDENTRY1(EDIT_UNDO_RED,"standard","undo",16)
	ICONIDENTRY1(ELEMENT_COPY,"TNTedit","copy_element",16)
	ICONIDENTRY1(ELEMENT_DELETE,"TNTedit","del_element",16)
	ICONIDENTRY1(ELEMENT_EDGE_CYAN,"TNTedit","edge_c",16)
	ICONIDENTRY1(ELEMENT_EDIT,"TNTedit","edit_element",16)
	ICONIDENTRY1(ELEMENT_GENERIC_RED,"TNTedit","element_red",16)
	ICONIDENTRY1(ELEMENT_GENERIC_BLUE,"TNTedit","element_blue",16)
	ICONIDENTRY1(ELEMENT_LABEL_CYAN,"TNTedit","label_c",16)
	ICONIDENTRY1(ELEMENT_LINE_BLUE,"TNTedit","line_blue",16)
	ICONIDENTRY1(ELEMENT_LINE_CYAN,"TNTedit","line_c",16)
	ICONIDENTRY1(ELEMENT_LINE_RED,"TNTedit","line",16)
	ICONIDENTRY1(ELEMENT_NODE_CYAN,"TNTedit","node_c",16)
	ICONIDENTRY1(ELEMENT_POINT_BLUE,"TNTedit","point_blue",16)
	ICONIDENTRY1(ELEMENT_POINT_CYAN,"TNTedit","point_c",16)
	ICONIDENTRY1(ELEMENT_POINT_RED,"TNTedit","point",16)
	ICONIDENTRY1(ELEMENT_POLYGON_BLUE,"TNTedit","polygon_blue",16)
	ICONIDENTRY1(ELEMENT_POLYGON_CYAN,"TNTedit","Polygon_c",16)
	ICONIDENTRY1(ELEMENT_POLYGON_RED,"TNTedit","polygon",16)
	ICONIDENTRY1(ELEMENT_TRIANGLE_CYAN,"TNTedit","triangle_c",16)
	ICONIDENTRY1(EXECUTE,"standard","Execute",16)
	ICONIDENTRY1(EXECUTE_RESUME,"standard","resume_exec",16)
	ICONIDENTRY1(FEATUREMAP_ATTACH_VECTOR,"featmap","attach_vector",16)
	ICONIDENTRY1(FEATUREMAP_CALIBRATE,"featmap","calibrate",16)
	ICONIDENTRY1(FEATUREMAP_CATEGORIES,"featmap","categories",16)
	ICONIDENTRY1(FEATUREMAP_DEFINE_SAMPLES,"featmap","define_samples",16)
	ICONIDENTRY1(FEATUREMAP_DRAW_MARKED,"featmap","draw_marked",16)
	ICONIDENTRY1(FEATUREMAP_DRAW_PROTOTYPES,"featmap","prototypes",16)
	ICONIDENTRY1(FEATUREMAP_GROW_AND_MARK,"featmap","grow_feature",16)
	ICONIDENTRY1(FEATUREMAP_MARK_FEATURES,"featmap","mark_features",16)
	ICONIDENTRY1(FEATUREMAP_PROTECT,"featmap","protect_areas",16)
	ICONIDENTRY1(FEATUREMAP_ROI,"featmap","mask",16)
	ICONIDENTRY1(FILE_BREAK_LOCK,"standard","unlock",16)
	ICONIDENTRY1(FILE_BROWSE,"standard","browse_",16)
	ICONIDENTRY1(FILE_INFO,"standard","file_info",16)
	ICONIDENTRY1(FILE_NEW,"standard","new",16)
	ICONIDENTRY1(FILE_OPEN,"standard","open_",16)
	ICONIDENTRY1(FILE_PACK,"standard","pack",16)
	ICONIDENTRY1(FILE_RENAME,"standard","rename",16)
	ICONIDENTRY1(FILE_SAVE,"standard","save",16)
	ICONIDENTRY1(FILE_SAVEAS,"standard","save_as_",16)
	ICONIDENTRY1(FILE_VALIDATE,"standard","file_validate",16)
	ICONIDENTRY1(FILETYPE_TERRAINTILESET,"RVCobjects","terraintileset",16)
	ICONIDENTRY1(FILETYPE_TILESET,"RVCobjects","tms",16)
	ICONIDENTRY1(FILTER_DISOLVE_POLYGON,"TNTedit","disolve_polygon",16)
	ICONIDENTRY1(FILTER_REMOVE_BUBBLES,"TNTedit","remove_bubbles",16)
	ICONIDENTRY1(FILTER_REMOVE_DANGLE,"TNTedit","remove_dangler",16)
	ICONIDENTRY1(FILTER_REMOVE_EXCESS_NODES,"TNTedit","rem_excess_node",16)
	ICONIDENTRY1(FILTER_REMOVE_ISLANDS,"TNTedit","remove_islands",16)
	ICONIDENTRY1(FILTER_REMOVE_SLIVER,"TNTedit","remove_sliver",16)
	ICONIDENTRY1(FILTER_SNAP,"standard","snap",16)
	ICONIDENTRY1(FILTER_SPLINE,"standard","spline",16)
	ICONIDENTRY1(FILTER_THIN_LINE,"standard","thin_line",16)
	ICONIDENTRY1(FOLDER_NAVIGATE_OUT,"standard","navigate_out",16)
	ICONIDENTRY1(FOLDER_NEW,"RVCobjects","create_folder",16)
	ICONIDENTRY1(GEOREF_ADD_CONTROL_PT,"georeference","add_control_pt",16)
	ICONIDENTRY1(GEOREF_ADD_HARD_EDGE,"georeference","add_hard_edge",16)
	ICONIDENTRY1(GEOREF_AUTO_REGISTER,"georeference","auto_register",16)
	ICONIDENTRY1(GEOREF_CLIP_REGION,"georeference","clip_region",16)
	ICONIDENTRY1(GEOREF_CP_AUTOCORRELATE_BLUE,"georeference","autocorr_b",16)
	ICONIDENTRY1(GEOREF_CP_AUTOCORRELATE_RED,"georeference","correlate",16)
	ICONIDENTRY1(GEOREF_CP_DFTZ_RED,"standard","add_3d",16)
	ICONIDENTRY1(GEOREF_CP_ESTIMATE_BLUE,"georeference","estimate_b",16)
	ICONIDENTRY1(GEOREF_CP_ESTIMATE_RED,"georeference","estimate",16)
	ICONIDENTRY1(GEOREF_CP_FIND,"georeference","find_control_pt",16)
	ICONIDENTRY1(GEOREF_CP_SELECT,"georeference","cp_select",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_ELEMENT_BLUE,"georeference","snaptoelement_b",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_ELEMENT_RED,"georeference","snap_to_element",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_ENDPT_BLUE,"georeference","snaptoendpt_b",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_ENDPT_RED,"georeference","snap_to_end_pt",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_GRID_RED,"georeference","snap_to_grid",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_VERTEX_BLUE,"georeference","snaptovertex_b",16)
	ICONIDENTRY1(GEOREF_CP_SNAP_TO_VERTEX_RED,"georeference","snap_to_vertex",16)
	ICONIDENTRY1(GEOREF_DEL_EDGES,"georeference","del_edges",16)
	ICONIDENTRY1(GEOREF_DEL_HARD_EDGES,"georeference","del_hard_edges",16)
	ICONIDENTRY1(GEOREF_DEL_REGION,"georeference","del_region",16)
	ICONIDENTRY1(GEOREF_DEL_TRIANGLES,"georeference","del_triangles",16)
	ICONIDENTRY1(GEOREF_FIND,"georeference","find",16)
	ICONIDENTRY1(GEOREF_GET_ELEVATION,"georeference","get_elevation",16)
	ICONIDENTRY1(GEOREF_RECOVER_DELETED,"georeference","recover_deleted",16)
	ICONIDENTRY1(GEOREF_SELECT_HARD_EDGE,"georeference","sel_hard_edge",16)
	ICONIDENTRY1(GEOREF_TIEPOINT,"georef","corresponder",16)
	ICONIDENTRY1(GOOGLE_EARTH,"standard","google_earth",16)
	ICONIDENTRY1(GRE_COORDSOURCE_GPS,"display16","gps_point",16)
	ICONIDENTRY1(GRE_COORDSOURCE_POINTER,"display16","mouse_point",16)
	ICONIDENTRY1(GRE_COORDSOURCE_USERENTERED,"display16","entered_point",16)
	ICONIDENTRY1(GRE_COORDSOURCE_VIEWCENTER,"display16","center_point",16)
	ICONIDENTRY1(GRE_GROUP_3D,"standard","surface",16)
	ICONIDENTRY1(GRE_GROUP_PAIR_OVERLAPPED,"georeference","overlap_view",16)
	ICONIDENTRY1(GRE_LAYER_ARCIMS,"standard","arcims_layer",16)
	ICONIDENTRY1(GRE_LAYER_GEOFORMULA,"display16","geoformula",16)
	ICONIDENTRY1(GRE_LAYER_MAPGRID,"standard","map_grid",16)
	ICONIDENTRY1(GRE_LAYER_PINMAP,"RVCobjects","pinmap",16)
	ICONIDENTRY1(GRE_LAYER_SCALEBAR,"standard","scale_bar",16)
	ICONIDENTRY1(GRE_LAYER_SCRIPT,"standard","sml",16)
	ICONIDENTRY1(GRE_LAYER_SKETCH,"display16","pencil",16)
	ICONIDENTRY1(GRE_LAYER_SURFACE,"standard","solidsurface",16)
	ICONIDENTRY1(GRE_LAYER_WIREFRAME,"standard","wireframe",16)
	ICONIDENTRY1(GRE_LAYER_WMS,"standard","wms_layer",16)
	ICONIDENTRY1(GRE_PROJECT_SETTINGS,"standard","group_controls",16)
	ICONIDENTRY1(GRIDTOOL_HEXAGON,"gridtool", "hexagon",16)
	ICONIDENTRY1(GRIDTOOL_ORIENTATION,"gridtool", "orientation",16)
	ICONIDENTRY1(GRIDTOOL_PARALLEL,"gridtool", "parallel",16)
	ICONIDENTRY1(GRIDTOOL_RANDOM_CLUSTER,"gridtool", "randomc",16)
	ICONIDENTRY1(GRIDTOOL_RANDOM_RECTANGLE,"gridtool", "rand_rectangle",16)
	ICONIDENTRY1(GRIDTOOL_RECTANGLE,"gridtool", "rectangle",16)
	ICONIDENTRY1(GRIDTOOL_REGULAR,"gridtool", "regular",16)
	ICONIDENTRY1(GRIDTOOL_SQUARE,"gridtool", "square",16)
	ICONIDENTRY1(GRIDTOOL_SYSTEMATIC_UNALIGNED,"gridtool", "sysunal",16)
	ICONIDENTRY1(GRIDTOOL_TRIANGLE,"gridtool", "triangle",16)
	ICONIDENTRY1(HELP,"standard","help",16)
	ICONIDENTRY1(HELP2,"standard","help2",16)
	ICONIDENTRY1(HELP3,"standard","help3",16)
	ICONIDENTRY1(HOT_KEY_INFO,"standard","hot_key_info",16)
	ICONIDENTRY1(INSERT_BEFORE,"small","insert_before",11)
	ICONIDENTRY1(HYPER_NAVIGATE_BACK,"arrows","previous",16)
	ICONIDENTRY1(HYPER_NAVIGATE_FORWARD,"arrows","next",16)
	ICONIDENTRY1(HYPER_NAVIGATE_HOME,"arrows","home",16)
	ICONIDENTRY1(JOB_QUEUE,"standard","queue_job",16)
	ICONIDENTRY1(JOB_SAVE,"standard","save_job",16)
	ICONIDENTRY1(LAYER_ADD_RED,"standard","add",16)
	ICONIDENTRY1(LAYER_ADD_YELLOW,"mosaic","add",16)
	ICONIDENTRY1(LAYER_BINGMAPS,"standard","bingmaps",16)
	ICONIDENTRY1(LAYER_BOTTOM_RED,"standard","to_bottom",16)
	ICONIDENTRY1(LAYER_BOTTOM_YELLOW,"mosaic","to_bottom",16)
	ICONIDENTRY1(LAYER_CONTROLS,"standard","layer_controls",16)
	ICONIDENTRY1(LAYER_DELETE_ALL_YELLOW,"mosaic","remove_all",16)
	ICONIDENTRY1(LAYER_DELETE_RED,"standard","remove",16)
	ICONIDENTRY1(LAYER_DELETE_YELLOW,"mosaic","remove",16)
	ICONIDENTRY1(LAYER_DOWN_RED,"standard","lower",16)
	ICONIDENTRY1(LAYER_DOWN_YELLOW,"mosaic","lower",16)
	ICONIDENTRY1(LAYER_PLAY_RED,"standard","draw_layer",16)
	ICONIDENTRY1(LAYER_TOOL_YELLOW,"standard","layerscontrol",16)
	ICONIDENTRY1(LAYER_TOP_RED,"standard","to_top",16)
	ICONIDENTRY1(LAYER_TOP_YELLOW,"mosaic","to_top",16)
	ICONIDENTRY1(LAYER_UP_RED,"standard","raise",16)
	ICONIDENTRY1(LAYER_UP_YELLOW,"mosaic","raise",16)
	ICONIDENTRY1(LINE_HORIZONTAL_RED,"standard","line_horz",16)
	ICONIDENTRY1(LINE_WAVY_RED,"standard","line_wavy",16)
	ICONIDENTRY1(LINE_ZIGZAG_RED,"standard","line_zigzag",16)
	ICONIDENTRY1(LINK_MENU_BLUE,"TNTedit","link_tools_blue",16)
	ICONIDENTRY1(LINK_SELECT_BLUE,"TNTedit","link_sel_blue",16)
	ICONIDENTRY1(LINK_VAR_13X13,"misc13x13","link_var",13)
	ICONIDENTRY1(LIST_COLLAPSE,"standard","collapse",16)
	ICONIDENTRY1(LIST_EXPAND,"standard","expand",16)
	ICONIDENTRY1(LOGO_MI,"processes32","logo",32)
	ICONIDENTRY1(LOCATOR,"standard","locator",16)
	ICONIDENTRY1(MATH_ADD,"standard","math_add",16)
	ICONIDENTRY1(MATH_DIVIDE,"standard","math_divide",16)
	ICONIDENTRY1(MATH_GROUP,"standard","math_group",16)
	ICONIDENTRY1(MATH_MAX,"small","max",11)
	ICONIDENTRY1(MATH_MEAN,"small","mean",11)
	ICONIDENTRY1(MATH_MIN,"small","min",11)
	ICONIDENTRY1(MATH_MULTIPLY,"standard","math_multiply",16)
	ICONIDENTRY1(MATH_N,"small","n",11)
	ICONIDENTRY1(MATH_POWER,"standard","math_power",16)
	ICONIDENTRY1(MATH_SIGMA,"small","sigma",11)
	ICONIDENTRY1(MATH_STDDEV,"small","stand_deviation",11)
	ICONIDENTRY1(MATH_SUBTRACT,"standard","math_subtract",16)
	ICONIDENTRY1(MATH_UNGROUP,"standard","math_ungroup",16)
	ICONIDENTRY1(MEASURE_CROSS_SECTION,"measurement","c_section",16)
	ICONIDENTRY1(MEASURE_HISTOGRAM,"measurement","histogram",16)
	ICONIDENTRY1(MEASURE_PROFILE,"measurement","profile",16)
	ICONIDENTRY1(MEASURE_PROTRACTOR,"measurement","protractor",16)
	ICONIDENTRY1(MESSAGES_ERROR,"messages","error",32)
	ICONIDENTRY1(MESSAGES_EXCLAMATION,"messages","exclamation",32)
	ICONIDENTRY1(MESSAGES_INFORMATION,"messages","information",32)
	ICONIDENTRY1(MESSAGES_PAUSE,"messages","pause2",32)
	ICONIDENTRY1(MESSAGES_PLAY,"messages","play",32)
	ICONIDENTRY1(MESSAGES_QUESTION,"messages","question",32)
	ICONIDENTRY1(MESSAGES_STOP,"messages","stop",32)
	ICONIDENTRY1(MESSAGES_WORK,"messages","work",32)
	ICONIDENTRY1(MORPHOLOGY_DIAGONAL,"morphology","diagonal",16)
	ICONIDENTRY1(MORPHOLOGY_LONG_LINE,"morphology","longl",16)
	ICONIDENTRY1(MORPHOLOGY_SHORT_LINE,"morphology","shortl",16)
	ICONIDENTRY1(MORPHOLOGY_TEE,"morphology","tee",16)
	ICONIDENTRY1(NAVIGATE_GOTO,"RVCobjects","go_to",16)
	ICONIDENTRY1(NEW_RECORD,"standard","new_record",16)
	ICONIDENTRY1(OPERATION_COGO,"cogo_set","cogo",16)
	ICONIDENTRY1(OPERATION_INTERACTIVE_LINE_FOLLOWING,"smartline","smart_line",16)
	ICONIDENTRY1(PADLOCK_CLOSED,"standard","padlock_closed",16)
	ICONIDENTRY1(PADLOCK_CLOSED_13X13,"misc13x13","locked",13)
	ICONIDENTRY1(PADLOCK_OPEN,"standard","padlock_open",16)
	ICONIDENTRY1(PAINT_BUCKET,"standard","paint_bucket",16)
	ICONIDENTRY1(POINT_PROFILE_TOOL,"standard","point_profile",16)
	ICONIDENTRY1(PREFERENCES_GENERAL,"standard","preferences",16)
	ICONIDENTRY1(PRINT,"standard","print",16)
	ICONIDENTRY1(PRINT_SNAPSHOT,"standard","print_snapshot",16)
	ICONIDENTRY1(RASTER_DRAW_WEDGE,"draw","draw_wedge",16)
	ICONIDENTRY1(RASTER_FILL_WEDGE,"draw","fill_wedge",16)
	ICONIDENTRY1(RASTER_DRAW_CHORD,"draw","chord",16)
	ICONIDENTRY1(RASTER_FILL_CHORD,"draw","fill_chord",16)
	ICONIDENTRY1(RASTER_DRAW_REGION,"draw","region",16)
	ICONIDENTRY1(RASTER_FILL_REGION,"draw","fill_region",16)
	ICONIDENTRY1(RASTER_FILTER,"draw","numfilter",16)
	ICONIDENTRY1(REORIENT_FLIP_HORIZONTAL,"standard15x15", "flip_h",16)
	ICONIDENTRY1(REORIENT_FLIP_VERTICAL,"standard15x15", "flip_v",16)
	ICONIDENTRY1(REORIENT_ROTATE_ANTICLOCKWISE,"standard15x15", "anticlockwise",16)
	ICONIDENTRY1(REORIENT_ROTATE_CLOCKWISE,"standard15x15", "clockwise",16)
	ICONIDENTRY1(REVERT_RASTER,"draw","revert_raster",16)
	ICONIDENTRY1(RASTER_DRAW_ARC,"draw","arc",16)
	ICONIDENTRY1(RECORD_MOVIE,"display16","record_movie",16)
	ICONIDENTRY1(REFERENCE_BOOK,"standard","ref_book",16)
	ICONIDENTRY1(REPAIR,"TNTedit","validate",16)
	ICONIDENTRY1(RVCOBJ_ALLTYPES,"RVCobjects","alltypes",16)
	ICONIDENTRY1(RVCOBJ_CAD,"RVCobjects","cad",16)
	ICONIDENTRY1(RVCOBJ_CAMERAINFO,"RVCobjects","cameracalib",16)
	ICONIDENTRY1(RVCOBJ_COLORPALETTE,"RVCobjects","color_map",16)
	ICONIDENTRY1(RVCOBJ_CONTRAST,"RVCobjects","contab",16)
	ICONIDENTRY1(RVCOBJ_DATABASE,"RVCobjects","db",16)
	ICONIDENTRY1(RVCOBJ_DB_QUERY,"RVCobjects","db_query",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE,"RVCobjects","db_table",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE_INTERNAL,"RVCobjects","internal_table",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE_LINKED,"RVCobjects","linked_table",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE_LINKED_MISSING,"RVCobjects","tab_link_missin",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE_STANDARD,"RVCobjects","standard_table",16)
	ICONIDENTRY1(RVCOBJ_DB_TABLE_STYLE,"RVCobjects","style_tab",16)
	ICONIDENTRY1(RVCOBJ_DBFORM,"RVCobjects","dbform",16)
	ICONIDENTRY1(RVCOBJ_DISP_GROUP,"RVCobjects","disp_group",16)
	ICONIDENTRY1(RVCOBJ_DISP_LAYOUT,"RVCobjects","disp_layout",16)
	ICONIDENTRY1(RVCOBJ_DISP_SIM3D,"RVCobjects","disp_sim3d",16)
	ICONIDENTRY1(RVCOBJ_DISP_TEMPLATE,"RVCobjects","layout_template",16)
	ICONIDENTRY1(RVCOBJ_DISPPARM,"RVCobjects","dispparm",16)
	ICONIDENTRY1(RVCOBJ_EDITPARM,"RVCobjects","editparm",16)
	ICONIDENTRY1(RVCOBJ_FILE,"RVCobjects","rvc_file",16)
	ICONIDENTRY1(RVCOBJ_FILTER,"RVCobjects","filter",16)
	ICONIDENTRY1(RVCOBJ_FOLDER,"RVCobjects","folder",16)
	ICONIDENTRY1(RVCOBJ_FREQPROCINFO,"RVCobjects","freqprocinfo",16)
	ICONIDENTRY1(RVCOBJ_GENERIC,"RVCobjects","unknown",16)
	ICONIDENTRY1(RVCOBJ_GEOREFERENCE,"RVCobjects","georef",16)
	ICONIDENTRY1(RVCOBJ_HISTOGRAM,"RVCobjects","histo",16)
	ICONIDENTRY1(RVCOBJ_HYPERLINKS,"RVCobjects","hyperlinks",16)
	ICONIDENTRY1(RVCOBJ_HYPERSPECTRAL,"RVCobjects","hyperspectral",16)
	ICONIDENTRY1(RVCOBJ_ICM,"RVCobjects","icm",16)
	ICONIDENTRY1(RVCOBJ_INTERNAL,"RVCobjects","internal",16)
	ICONIDENTRY1(RVCOBJ_LEGEND,"RVCobjects","legend",16)
	ICONIDENTRY1(RVCOBJ_LIDAR,"RVCobjects","lidar",16)
	ICONIDENTRY1(RVCOBJ_MAP,"RVCobjects","map",16)
	ICONIDENTRY1(RVCOBJ_METADATA,"RVCobjects","metadata",16)
	ICONIDENTRY1(RVCOBJ_RASTER,"RVCobjects","raster",16)
	ICONIDENTRY1(RVCOBJ_RASTER_BLUE,"RVCobjects","blue_contrast",16)
	ICONIDENTRY1(RVCOBJ_RASTER_CYAN,"","",16)
	ICONIDENTRY1(RVCOBJ_RASTER_GRAY,"RVCobjects","intensity",16)
	ICONIDENTRY1(RVCOBJ_RASTER_GREEN,"RVCobjects","green_contrast",16)
	ICONIDENTRY1(RVCOBJ_RASTER_HUE,"RVCobjects","hue",16)
	ICONIDENTRY1(RVCOBJ_RASTER_MAGENTA,"","",16)
	ICONIDENTRY1(RVCOBJ_RASTER_MULTIBAND,"RVCobjects","rastermultiband",16)
	ICONIDENTRY1(RVCOBJ_RASTER_RED,"RVCobjects","red_contrast",16)
	ICONIDENTRY1(RVCOBJ_RASTER_SATURATION,"RVCobjects","saturation",16)
	ICONIDENTRY1(RVCOBJ_RASTER_YELLOW,"","",16)
	ICONIDENTRY1(RVCOBJ_REGION,"RVCobjects","region",16)
	ICONIDENTRY1(RVCOBJ_SATELLITEINFO,"RVCobjects","spotheader",16)
	ICONIDENTRY1(RVCOBJ_SHAPE,"RVCobjects","shape",16)
	ICONIDENTRY1(RVCOBJ_SMLSCRIPT,"RVCobjects","sml",16)
	ICONIDENTRY1(RVCOBJ_SPATIALTREE,"RVCobjects","qtree",16)
	ICONIDENTRY1(RVCOBJ_SPECTRAL,"RVCobjects","spectral",16)
	ICONIDENTRY1(RVCOBJ_STYLE,"RVCobjects","style",16)
	ICONIDENTRY1(RVCOBJ_TEXT,"RVCobjects","text",16)
	ICONIDENTRY1(RVCOBJ_TIEPOINT,"RVCobjects","tiepts",16)
	ICONIDENTRY1(RVCOBJ_TIN,"RVCobjects","tin",16)
	ICONIDENTRY1(RVCOBJ_VECTOR,"RVCobjects","vector",16)
	ICONIDENTRY1(SDE_AUTO_GENERATE_LABEL,"standard","auto_label_gen",16)
	ICONIDENTRY1(SDE_BREAK_LINE,"standard","break_line",16)
	ICONIDENTRY1(SDE_CONVERT_NODE_TO_POINT,"TNTedit","nodetopoint",16)
	ICONIDENTRY1(SDE_ELEMENT_OFFSET,"polyline_edit","element_offset",16)
	ICONIDENTRY1(SDE_ELEMENT_ORDER,"standard","order_elements",16)
	ICONIDENTRY1(SDE_ELEMENT_STYLE,"TNTedit","element_style",16)
	ICONIDENTRY1(SDE_ELEVATION_FROM_SURFACE,"TNTedit","set_servac_elev",16)
	ICONIDENTRY1(SDE_FILL_BOUNDARY,"standard","boundary_fill",16)
	ICONIDENTRY1(SDE_FILL_FLOOD,"standard","flood_fill",16)
	ICONIDENTRY1(SDE_FILL_RASTER,"standard","process_raster",16)
	ICONIDENTRY1(SDE_FILL_SMART,"standard","smart_fill",16)
	ICONIDENTRY1(SDE_FILL_VISIBLE,"standard","process_window",16)
	ICONIDENTRY1(SDE_HARDEN_AUTO_LABEL,"TNTedit","harden_label",16)
	ICONIDENTRY1(SDE_JOIN_LINES,"standard","join_lines",16)
	ICONIDENTRY1(SDE_LABEL_ATTRIBUTES,"standard","label_attribs",16)
	ICONIDENTRY1(SDE_MOVE_ELEMENT,"TNTedit","move_element",16)
	ICONIDENTRY1(SDE_NUMERIC_EDIT,"standard","num_edit",16)
	ICONIDENTRY1(SDE_REVERSE_LINE_VERTICES,"standard","rev_line_points",16)
	ICONIDENTRY1(SDE_SEPARATE_COMPLEX_ELEMENTS,"TNTedit","explode_multi",16)
	ICONIDENTRY1(SDE_STRAIGHTEN_LINE,"standard","straighten_line",16)
	ICONIDENTRY1(SDE_TRACE_REFERENCE_LINE,"smartline","trace",16)
	ICONIDENTRY1(SELECT_ALL_CYAN,"standard","all_elements",16)
	ICONIDENTRY1(SELECT_BANDS_RGB,"standard","select_bands",16)
	ICONIDENTRY1(SELECT_BOX_CYAN,"standard","box_select",16)
	ICONIDENTRY1(SELECT_BY_QUERY_CYAN,"standard","query_select",16)
	ICONIDENTRY1(SELECT_CIRCLE_CYAN,"standard","circle_select",16)
	ICONIDENTRY1(SELECT_CLEAR_CYAN,"standard","select_clear",16)
	ICONIDENTRY1(SELECT_INVERT_CYAN,"standard","select_invert",16)
	ICONIDENTRY1(SELECT_MINUS_CYAN,"standard","minus_select",16)
	ICONIDENTRY1(SELECT_MULTI_CYAN,"standard","multiple_select",16)
	ICONIDENTRY1(SELECT_NEXT_RED,"TNTedit","next_element",16)
	ICONIDENTRY1(SELECT_ONE_CYAN,"standard","one_select",16)
	ICONIDENTRY1(SELECT_PLUS_CYAN,"standard","add_select",16)
	ICONIDENTRY1(SELECT_POLYGON_CYAN,"standard","polygon_select",16)
	ICONIDENTRY1(SELECT_PREVIOUS_RED,"TNTedit","prev_element",16)
	ICONIDENTRY1(SELECT_REGION_CYAN,"standard","select_region",16)
	ICONIDENTRY1(SELECT_SINGLE_CYAN,"standard","single_select",16)
	ICONIDENTRY1(SELECT_TOGGLE_CYAN,"standard","toggle_select",16)
	ICONIDENTRY1(SELECT_UNDO_CYAN,"standard","unselect",16)
	ICONIDENTRY1(SET_ALL_LEVELS,"standard","set_all_levels",16)
	ICONIDENTRY1(SET_CONTOUR_ELEVATION,"TNTedit","set_contourelev",16)
	ICONIDENTRY1(SET_SELECTED_LEVELS,"standard","set_selected",16)
	ICONIDENTRY1(SMALL_BLANK,"small","blank13x13",11)
	ICONIDENTRY1(SMALL_DELETE,"small","delete",11)
	ICONIDENTRY1(SMALL_BROWSE,"small","browse_small",11)
	ICONIDENTRY1(SML_ASSEMBLY,"standard","sml_assembly",16)
	ICONIDENTRY1(SML_BREAK_AND_PC,"standard","break_and_pc",16)
	ICONIDENTRY1(SML_BREAKPOINT,"standard","red_ball",16)
	ICONIDENTRY1(SML_INSERT,"standard","sml_insert",16)
	ICONIDENTRY1(SML_INSERT2,"standard","sml_insert2",16)
	ICONIDENTRY1(SML_PC,"standard","pc",16)
	ICONIDENTRY1(SML_STEP,"standard","play_field",16)
	ICONIDENTRY1(SML_SYNTAX,"standard","sml_syntax",16)
	ICONIDENTRY1(SML_TIMINGS,"standard","clock",16)
	ICONIDENTRY1(SNAPSHOT,"standard","snapshot_",16)
	ICONIDENTRY1(SQUARE_OPEN_SMALL,"small","square_empty",11)
	ICONIDENTRY1(SQUARE_ON_BLACK_SMALL,"small","square_on_black",11)
	// Do NOT prefix names with "STANDARD", put in appropriate grouping, discuss if unsure!
	ICONIDENTRY1(STANDARD_EXTENTS,"standard","extents",16)
	ICONIDENTRY1(STANDARD_GOTO_LINE,"standard","goto_line",16)
	// Do NOT prefix names with "STANDARD", put in appropriate grouping, discuss if unsure!
	ICONIDENTRY1(STYLE_PATTERN_COPY,"pat_select","copy",16)
	ICONIDENTRY1(STYLE_PATTERN_EDIT,"pat_select","edit",16)
	ICONIDENTRY1(STYLE_PATTERN_EDITSET,"pat_select","edit_set",16)
	ICONIDENTRY1(STYLE_PATTERN_NEW,"pat_select","new",16)
	ICONIDENTRY1(STYLE_STYLE_COPY,"pat_select","copy_style",16)
	ICONIDENTRY1(STYLE_STYLE_NEW,"pat_select","new_style",16)
	ICONIDENTRY1(STYLE_VIEW_ICONS,"pat_select","icon_only",16)
	ICONIDENTRY1(STYLE_VIEW_LIST,"pat_select","icon_and_name",16)
	ICONIDENTRY1(SUBTRACT_POLYLINE_RED,"TNTedit","subtract_line",16)
	ICONIDENTRY1(TEXT_BOLD,"standard","bold",16)
	ICONIDENTRY1(TEXT_CENTER_JUSTIFY,"standard","centerjustify",16)
	ICONIDENTRY1(TEXT_ENHANCED,"standard","enhanced",16)
	ICONIDENTRY1(TEXT_FONT,"standard","textfont",16)
	ICONIDENTRY1(TEXT_FORMAT,"draw","text",16)
	ICONIDENTRY1(TEXT_FULL_JUSTIFY,"standard","fulljustify",16)
	ICONIDENTRY1(TEXT_ITALICS,"standard","italic",16)
	ICONIDENTRY1(TEXT_LEFT_JUSTIFY,"standard","leftjustify",16)
	ICONIDENTRY1(TEXT_OUTLINE,"standard","outline",16)
	ICONIDENTRY1(TEXT_RIGHT_JUSTIFY,"standard","rightjustify",16)
	ICONIDENTRY1(TEXT_SHADOW,"standard","shadow",16)
	ICONIDENTRY1(TEXT_UNDERLINE,"standard","underline",16)
	ICONIDENTRY1(TITLE_TNTMIPS,"standard","TNTmips",16)
	ICONIDENTRY1(TITLE_TNTSERVER,"standard","TNTserver",16)
	ICONIDENTRY1(TOOL_SNAPGRID,"polyline_edit","grid_snap",16)
	ICONIDENTRY1(TOOLBOX_ARC,"measurement","arc",16)
	ICONIDENTRY1(TOOLBOX_ARC_CHORD,"measurement","arc_chord",16)
	ICONIDENTRY1(TOOLBOX_ARC_WEDGE,"measurement","arc_wedge",16)
	ICONIDENTRY1(TOOLBOX_CIRCLE,"measurement","circle",16)
	ICONIDENTRY1(TOOLBOX_ELLIPSE,"measurement","ellipse",16)
	ICONIDENTRY1(TOOLBOX_POINT,"measurement","point",16)
	ICONIDENTRY1(TOOLBOX_POLYGON,"measurement","polygon",16)
	ICONIDENTRY1(TOOLBOX_POLYLINE,"measurement","polyline",16)
	ICONIDENTRY1(TOOLBOX_RECTANGLE,"measurement","rectangle",16)
	ICONIDENTRY1(TOOLBOX_REGION,"measurement","region",16)
	ICONIDENTRY1(TOOLBOX_REGULAR_POLYGON,"measurement","regpol",16)
	ICONIDENTRY1(TOOLBOX_SEGMENT,"measurement","line",16)
	ICONIDENTRY1(TOOLBOX_TEXT,"measurement","text",16)
	ICONIDENTRY1(TOOLPOLYLINE_ADDSTART,"polyline_edit","add_start",16)
	ICONIDENTRY1(TOOLPOLYLINE_ADDEND,"polyline_edit","add_end",16)
	ICONIDENTRY1(TOOLPOLYLINE_DELETEVERTEX,"polyline_edit","delete_vertex2",16)
	ICONIDENTRY1(TOOLPOLYLINE_DRAGVERTEX,"polyline_edit","drag_vertex",16)
	ICONIDENTRY1(TOOLPOLYLINE_INSERTVERTEX,"polyline_edit","insert_vertex",16)
	ICONIDENTRY1(TOOLPOLYLINE_DRAW,"polyline_edit","draw_polygon",16)
	ICONIDENTRY1(TOOLPOLYLINE_STRETCH,"polyline_edit","stretch",16)
	ICONIDENTRY1(TOOLPOLYLINE_CLOSE,"polyline_edit","close_polygon",16)
	ICONIDENTRY1(TOOLPOLYLINE_MOVELINE,"polyline_edit","move_line",16)
	ICONIDENTRY1(TOOLRECTANGLE_LOWERLEFT,"polyline_edit","ll",16)
	ICONIDENTRY1(TOOLRECTANGLE_LOWERRIGHT,"polyline_edit","lr",16)
	ICONIDENTRY1(TOOLRECTANGLE_ORIENT_HORIZONTAL_ANGLE_UP,"measurement","recthrz_angleup",16)
	ICONIDENTRY1(TOOLRECTANGLE_ORIENT_VERTICAL_ANGLE_RIGHT,"measurement","rectvrt_anglert",16)
	ICONIDENTRY1(TOOLRECTANGLE_UPPERLEFT,"polyline_edit","ul",16)
	ICONIDENTRY1(TOOLRECTANGLE_UPPERRIGHT,"polyline_edit","ur",16)
	ICONIDENTRY1(UP_RED,"small","up_red",16)
	ICONIDENTRY1(VALUERANGE,"standard","valuerange",16)
	ICONIDENTRY1(VIEW_3DVIEWPOINT,"display16","adjust_view_pt",16)
	ICONIDENTRY1(VIEW_ACTIVE_ELEMENT,"standard","view_active",16)
	ICONIDENTRY1(VIEW_ALL_ELEMENTS,"standard","view_all",16)
	ICONIDENTRY1(VIEW_BLACK_TRANSPARENT,"standard","transp_black",16)
	ICONIDENTRY1(VIEW_GEOLOCK,"standard","copy_map",16)
	ICONIDENTRY1(VIEW_GLASSES_BLACK,"display16","not_visible",16)
	ICONIDENTRY1(VIEW_GLASSES_CYAN,"display16","visible",16)
	ICONIDENTRY1(VIEW_PREVIOUS_CYAN,"standard","previous_view",16)
	ICONIDENTRY1(VIEW_SELECTED_ELEMENTS,"standard","view_select",16)
	ICONIDENTRY1(VIEW_STEREO,"standard","stereo",16)
	ICONIDENTRY1(VIEW_TOOL_EXAMINERASTER,"standard","examine_raster",16)
	ICONIDENTRY1(VIEW_TOOL_GEOTOOLBOX,"standard","tools",16)
	ICONIDENTRY1(VIEW_TOOL_HYPEREDIT,"standard","hyper_link",16)
	ICONIDENTRY1(VIEW_TOOL_HYPERNAVIGATE,"standard","hyper_index",16)
	ICONIDENTRY1(VIEW_TOOL_PLACEMENT,"standard","group_placement",16)
	ICONIDENTRY1(VIEW_TOOL_RECENTER,"standard","recenter",16)
	ICONIDENTRY1(VIEW_TOOL_VIEWINVIEW,"standard","view_in_view",16)
	ICONIDENTRY1(VIEW_TOOL_ZOOMBOX,"standard","zoom_box",16)
	ICONIDENTRY1(VIEW_WHITE_TRANSPARENT,"standard","transp_white",16)
	ICONIDENTRY1(WATERSHED_COMPUTE_FP_B,"watershed","compute_flo_bas",16)
	ICONIDENTRY1(WATERSHED_DEPRESSION,"watershed","depression",16)
	ICONIDENTRY1(WATERSHED_FILL_DEPR,"watershed","fill_all_depr",16)
	ICONIDENTRY1(WATERSHED_FILL_DEPR_BY_QUERY,"watershed","fill_by_query",16)
	ICONIDENTRY1(WATERSHED_FILL_DOUBLE,"watershed","filldoublepour",16)
	ICONIDENTRY1(WATERSHED_FILL_LOWER,"watershed","fill_lower",16)
	ICONIDENTRY1(WATERSHED_FILL_UPPER,"watershed","fill_upper",16)
	ICONIDENTRY1(WATERSHED_FIND_DEPR,"watershed","find_depr",16)
	ICONIDENTRY1(WATERSHED_HISTOGRAM,"watershed","histogram",16)
	ICONIDENTRY1(WATERSHED_MOVE_THRU_LOW,"watershed","mov_thru_low",16)
	ICONIDENTRY1(WATERSHED_MOVE_THRU_UP,"watershed","mov_thru_up",16)
	ICONIDENTRY1(WATERSHED_NEXT_DEPR,"watershed","next_depr",16)
	ICONIDENTRY1(WATERSHED_NEXT_DOUBLE,"watershed","next_double",16)
	ICONIDENTRY1(WATERSHED_NEXT_LOW_POURS,"watershed","nextlowpourpts",16)
	ICONIDENTRY1(WATERSHED_NEXT_UP_POURS,"watershed","nextuppourpts",16)
	ICONIDENTRY1(WATERSHED_NEXT_WTR,"watershed","next_wtr",16)
	ICONIDENTRY1(WATERSHED_ONE_OR_MORE,"watershed","one_or_more",16)
	ICONIDENTRY1(WATERSHED_POUR_POINT,"watershed","pour_point",16)
	ICONIDENTRY1(WATERSHED_PREV_DEPR,"watershed","prev_depr",16)
	ICONIDENTRY1(WATERSHED_PREV_DOUBLE,"watershed","prev_double",16)
	ICONIDENTRY1(WATERSHED_PREV_LOW_POURS,"watershed","prevlowpourpts",16)
	ICONIDENTRY1(WATERSHED_PREV_UP_POURS,"watershed","prevuppourpts",16)
	ICONIDENTRY1(WATERSHED_PREV_WTR,"watershed","prev_wtr",16)
	ICONIDENTRY1(WATERSHED_REMOVE_NOISE,"watershed","remove_noise",16)
	ICONIDENTRY1(WATERSHED_SELECT_WTR,"watershed","polygon",16)
	ICONIDENTRY1(WATERSHED_SET_TO_DEFAULT,"watershed","set_to_default",16)
	ICONIDENTRY1(WATERSHED_SHOW_BASIN,"watershed","show_basin",16)
	ICONIDENTRY1(WATERSHED_SHOW_FP,"watershed","show_flowpath",16)
	ICONIDENTRY1(WATERSHED_SHOW_RIDGE,"watershed","show_ridge",16)
	ICONIDENTRY1(WATERSHED_SHOW_WTR,"watershed","show_watershed",16)
	ICONIDENTRY1(ZOOM_1,"standard","zoom_1x",16)
	ICONIDENTRY1(ZOOM_2,"standard","zoom_2x",16)
	ICONIDENTRY1(ZOOM_3,"standard","zoom_3x",16)
	ICONIDENTRY1(ZOOM_4,"standard","zoom_4x",16)
	ICONIDENTRY1(ZOOM_CYAN,"standard","zoom_cyan",16)
	ICONIDENTRY1(ZOOM_FULL,"standard","full_view",16)
	ICONIDENTRY1(ZOOM_FULL_EXTENTS,"standard","extents",16)
	ICONIDENTRY1(ZOOM_IN,"standard","zoom_in",16)
	ICONIDENTRY1(ZOOM_MAX_DETAIL,"standard","pan_to_center",16)
	ICONIDENTRY1(ZOOM_OUT,"standard","zoom_out",16)
	ICONIDENTRY1(ZOOM_TO_GROUP,"display16","zoom_to_group",16)
	ICONIDENTRY1(ZOOM_TO_LAYER,"display16","zoom_to_layer",16)
	ICONIDENTRY1(ZOOM_TO_LOCATION,"standard","zoomtolocation",16)
	ICONIDENTRY1(ZOOM_UNDO,"standard","previous_zoom",16)
	// ADD ITEMS IN ALPHABETICAL ORDER!
	ICONIDENTRYLAST
	};

#undef	ICONIDTABLE
#undef	ICONIDENTRY1
#undef	ICONIDENTRY2
#undef	ICONIDENTRY3
#undef	ICONIDENTRYLAST

#endif // GENERATING_DOXYGEN_OUTPUT
#endif // INC_MI32_ICONID_H

