/**
 * \file midblary.h <mi32/midblary.h>
 * \brief Definitions for MIDOUBLEARRAY class
 *
 * \if NODOC
 * $Id: midblary.h_v 1.6 2006/01/30 17:31:32 mju Exp $
 *
 * $Log: midblary.h_v $
 * Revision 1.6  2006/01/30 17:31:32  mju
 * Add const getPointer inline.
 *
 * Revision 1.5  2005/09/01 15:43:48  mju
 * Undef classlibexport at end.
 *
 * Revision 1.4  2003/09/15 13:49:56  fileserver!dwilliss
 * Doxygen
 *
 * Revision 1.3  2002/05/17 19:47:23  dwilliss
 * Export even on the Mac using their non-standard way.
 *
 * Revision 1.2  2002/05/14 20:31:32  dwilliss
 * Added a newline to the end of the file to make gcc shut up about it
 *
 * Revision 1.1  2001/05/16 17:13:34  scowan
 * Initial revision
 * \endif
**/

#ifndef	INC_MI32_MIDBLARY_H
#define	INC_MI32_MIDBLARY_H

#ifndef	INC_MI32_STDDEFNS_H
	#include <mi32/stddefns.h>
#endif

#ifdef MISYSTEMDLL
	#define CLASSLIBEXPORT MI_DLLCLASSEXPORT
#else
	#define CLASSLIBEXPORT MI_DLLCLASSIMPORT
#endif

//!	MIDOUBLEARRAY class exists to solve an issue with some OS's that cannot correctly align a buffer of double's on a double boundary.
//! Not aligning on a double boundary can cause a speed penalty on some platforms.  This class creates a buffer that is forced to be 
//! double aligned.  This is exported from MISYSTEM.DLL and must not be inherited from.  Currently DOUBLE_ARRAY<> and POLYLINE classes 
//! use this class as their foundation.  Thise classes should meet most of your needs.

class CLASSLIBEXPORT MIDOUBLEARRAY {
	public:

		//! Default Constructor
		MIDOUBLEARRAY (
			);

		//! Copy Constructor
		MIDOUBLEARRAY (
			const MIDOUBLEARRAY& rhs
			);

		//! Destructor
		~MIDOUBLEARRAY (
			);
			
		//! Assignment.
		MIDOUBLEARRAY& operator= (
			const MIDOUBLEARRAY& rhs
			);
			
		//! Attach a MIDOUBLEARRAY to this one and clear out 'rhs'
		void Attach (
			MIDOUBLEARRAY& rhs
			);

		//! Free MIDOUBLEARRAY buffer
		void Free (
			);
		
		//! Get const pointer to internal buffer.
		//! @return Pointer to correctly aligned double array buffer
		const double* GetPointer (
			) const { return (m_items); }
			
		//! Get pointer to internal buffer.
		//! DO NOT REALLOCATE OR FREE THIS POINTER, YOU WILL CRASH
		//!
		//! @return Pointer to correctly aligned double array buffer
		double* GetPointer (
			);
			
		//! Get reserved size of buffer in doubles
		//!
		//! @return Size of reserved buffer in doubles
		int GetNumReserved (
			) const;

		//! Reserve number of doubles in the array		
		ERRVALUE Reserve (
			INT32 NewSize,
			bool keepold = false
			);
			
		//! Reserve number of doubles in the array, throws exception if error
		void ReserveExc (
			INT32 NewSize,
			bool keepold = false
			);

		//! Swap buffers between 'this' and 'rhs'		
		void Swap (
			MIDOUBLEARRAY& rhs
			);
			
	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT

		double *m_items;							//!< The accessed array
		void *m_buffer;							//!< The allocated array
		int m_BufferSize;							//!< Size of buffer in bytes
		
		void Allocate (
			int NewSize
			);

		ERRVALUE AllocateWithErr (
			int NewSize
			);
		#endif // GENERATING_DOXYGEN_OUTPUT

	};

#undef CLASSLIBEXPORT

#endif		// INC_MI32_MIDBLARY_H

