/****
 *	\file mi32\registry.h
 *	\brief Class REGISTRY - Handle registry API's through this class
 * \if NODOC
 * $Id: registry.h_v 1.13 2007/05/25 21:30:53 scowan Exp $
 *
 * $Log: registry.h_v $
 * Revision 1.13  2007/05/25 21:30:53  scowan
 * Added grantWriteAccessTo method.
 *
 * Revision 1.12  2007/05/17 19:41:06  scowan
 * Added date time class storage methods.
 *
 * Revision 1.11  2006/12/08 18:51:39  scowan
 * Added patchTo method.
 *
 * Revision 1.10  2006/11/22 17:55:02  scowan
 * Added bitset unowned variants for get and set values.
 *
 * Revision 1.9  2006/10/09 15:08:21  scowan
 * Forward declare filepath, filepathlist, mistring, mistringlist.
 *
 * Revision 1.8  2006/10/04 14:58:49  scowan
 * Added simple array uint8 version of get and set values.
 *
 * Revision 1.7  2006/04/13 19:15:57  scowan
 * *** empty log message ***
 *
 * Revision 1.6  2006/04/12 20:29:16  scowan
 * Attempt to fix doxygen docs.
 *
 * Revision 1.5  2006/03/20 17:24:26  scowan
 * Fixed doxygen issues.
 *
 * Revision 1.4  2005/05/18 17:33:48  scowan
 * Aded save and restore methods.
 *
 * Revision 1.3  2005/01/21 22:07:08  scowan
 * Added flag.
 *
 * Revision 1.2  2005/01/11 00:30:57  scowan
 * Added methods.
 *
 * Revision 1.1  2004/12/27 22:38:04  scowan
 * Initial revision
 *
 * \endif
****/

#ifndef	INC_MI32_REGISTRY_H
#define	INC_MI32_REGISTRY_H

#if defined(WIN32)
#ifndef GENERATING_DOXYGEN_OUTPUT
#include <windows.h>
#endif	// GENERATING_DOXYGEN_OUTPUT

#ifndef INC_MI32_STDDEFNS_H
	#include <mi32/stddefns.h>
#endif

#ifndef INC_MI32_SIMPLEAR_H
	#include <mi32/simplear.h>
#endif

#ifndef GENERATING_DOXYGEN_OUTPUT
// Forward declarations
class BITSET_UNOWNED;
class DATETIME;
class FILEPATH;
class FILEPATHLIST;
class MISTRING;
class MISTRINGLIST;
#endif	// GENERATING_DOXYGEN_OUTPUT

#ifdef MISYSTEMDLL
	#define CLASSLIBEXPORT MI_DLLCLASSEXPORT
#else
	#define CLASSLIBEXPORT MI_DLLCLASSIMPORT
#endif

//! The REGISTRY class is a wrapper around the Windows Registry functions and deals
//! with the common classes and POD's that MicroImages uses on a regular basis.  This
//! is not meant to be used as a replacement for the INI functions and methods as this 
//! only works on Windows machines.  

//! Class for Windows registry functions.
class CLASSLIBEXPORT REGISTRY {
	public:

		enum ACCESS {
			ACCESS_Read,
			ACCESS_Write,
			ACCESS_Notify,
			ACCESS_All
			};

		//! Defined enum's for windows base registry keys.
		enum BASE {
			BASE_ClassesRoot,
			BASE_CurrentUser,
			BASE_LocalMachine,
			BASE_Users
			};

		REGISTRY (
			);

		REGISTRY (
			const REGISTRY& rhs
			);

		~REGISTRY (
			);

		REGISTRY& operator= (
			const REGISTRY& rhs
			);

		//! Close an open subkey
		void Close (
			);

		//! Create a subkey under the current key
		ERRVALUE CreateKey (
			const char* name,
			REGISTRY& DestKey					//!< Destination key RETURNED
			);

		//! Create a subkey under the current key
		ERRVALUE CreateKey (
			const MISTRING& name,
			REGISTRY& DestKey					//!< Destination key RETURNED
			);

		//! Delete the given subkey.  
		//! Will not work if the subkey itself has subkeys
		void DeleteSubKey (
			const char* name
			);

		//! Delete the given subkey.  
		//! Will not work if the subkey itself has subkeys
		void DeleteSubKey (
			const MISTRING& name
			);

		void DeleteAllSubKeys (
			);

		//! Get the list of key names under the current key
		void GetKeyNames (
			MISTRINGLIST& KeyList
			) const;

		//! Retrieve value given as a bool value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of (value != 0)
		void GetValue (
			const char* name,
			bool& value,
			const bool dft = false
			) const;

		//! Retrieve value given as a bool value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of (value != 0)
		void GetValue (
			const MISTRING& name,
			bool& value,
			const bool dft = false
			) const;

		//! Retrieve values given as a BITSET_UNOWNED value.
		//! The values are stored as "Yes' and 'No' (or 1 and 0) entries in a multi-string.  This will convert the strings into the BITSET_UNOWNED.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of (value != 0)
		void GetValue (
			const char* name,
			BITSET_UNOWNED& value,
			const bool dft = false
			) const;

		//! Retrieve value given as a bool value.
		//! The values are stored as "Yes' and 'No' (or 1 and 0) entries in a multi-string.  This will convert the strings into the BITSET_UNOWNED.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of (value != 0)
		void GetValue (
			const MISTRING& name,
			BITSET_UNOWNED& value,
			const bool dft = false
			) const;

		//! Retrieve value given as a UINT64 value.
		//! @return The default value given if the value does not exist or is not a REG_SZ value type, or the result of atoi(value)
		void GetValue (
			const char* name,
			UINT64& value,
			const UINT64 dft,
			const UINT64 min,
			const UINT64 max
			) const;

		//! Retrieve value given as a UINT64 value.
		//! @return The default value given if the value does not exist or is not a REG_SZ value type, or the result of atoi(value)
		void GetValue (
			const MISTRING& name,
			UINT64& value,
			const UINT64 dft,
			const UINT64 min,
			const UINT64 max
			) const;

		//! Retrieve value given as a UINT32 value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of value
		void GetValue (
			const char* name,
			UINT32& value,
			const UINT32 dft = 0,
			const UINT32 min = 0,
			const UINT32 max = 0
			) const;

		//! Retrieve value given as a UINT32 value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of value
		void GetValue (
			const MISTRING& name,
			UINT32& value,
			const UINT32 dft = 0,
			const UINT32 min = 0,
			const UINT32 max = 0
			) const;

		//! Retrieve value given as a INT32 value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of value
		void GetValue (
			const char* name,
			INT32& value,
			const INT32 dft = 0,
			const INT32 min = 0,
			const INT32 max = 0
			) const;

		//! Retrieve value given as a INT32 value.
		//! @return The default value given if the value does not exist or is not a REG_DWORD value type, or the result of value
		void GetValue (
			const MISTRING& name,
			INT32& value,
			const INT32 dft = 0,
			const INT32 min = 0,
			const INT32 max = 0
			) const;

		//! Retrieve value given as a MISTRING value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_SZ.
		void GetValue (
			const char* name,
			MISTRING& newstring
			) const;

		//! Retrieve value given as a MISTRING value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_SZ.
		void GetValue (
			const MISTRING& name,
			MISTRING& newstring
			) const;

		//! Retrieve value given as a MISTRINGLIST value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_MULTI_SZ.
		void GetValue (
			const char* name,
			MISTRINGLIST& StrList
			) const;

		//! Retrieve value given as a MISTRINGLIST value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_MULTI_SZ.
		void GetValue (
			const MISTRING& name,
			MISTRINGLIST& StrList
			) const;

		//! Retrieve value given as a FILEPATH value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_SZ.
		void GetValue (
			const char* name,
			FILEPATH& filepath
			) const;

		//! Retrieve value given as a FILEPATH value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_SZ.
		void GetValue (
			const MISTRING& name,
			FILEPATH& filepath
			) const;

		//! Retrieve value given as a FILEPATHLIST value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_MULTI_SZ.
		void GetValue (
			const char* name,
			FILEPATHLIST& PathList
			) const;

		//! Retrieve value given as a FILEPATHLIST value.
		//! @return The string stored or an empty string if the values does not exist or it is not of type REG_MULTI_SZ.
		void GetValue (
			const MISTRING& name,
			FILEPATHLIST& PathList
			) const;

		//! Retrieve binary value given as a SIMPLE_ARRAY<UINT8> value.
		//! @return The binary stored or an empty simple array if the value does not exist or it is not of type REG_BINARY.
		void GetValue (
			const char* name,
			SIMPLE_ARRAY<UINT8>& binary
			) const;

		//! Retrieve binary value given as a SIMPLE_ARRAY<UINT8> value.
		//! @return The binary stored or an empty simple array if the value does not exist or it is not of type REG_BINARY.
		void GetValue (
			const MISTRING& name,
			SIMPLE_ARRAY<UINT8>& binary
			) const;

		//! Retrieve DATETIME value
		//! Stored as a 64 bit value from DATETIME::GetNanoTime() in UTC
		void GetValue (
			const char* name,
			DATETIME& dt
			) const;

		//! Retrieve DATETIME value
		//! Stored as a 64 bit value from DATETIME::GetNanoTime() in UTC
		void GetValue (
			const MISTRING& name,
			DATETIME& dt
			) const;

		//! Get the list of value names under the current key
		void GetValueNames (
			MISTRINGLIST& NameList
			) const;

		//! Grant user account write access to the current registry key.
		//! Does not change the open access state of 'this'.
		//! @return 'True' if succeeded, false if not.
		bool GrantWriteAccessTo (
			const MISTRING& AccountName			//!< If string is empty, the account the the process is running under will be used
			);

		//! Determine if this instance is open
		//! @return 'True' if open, 'false' if not
		bool IsOpen (
			) const;

		//! Determine if the child key exists.
		//! @return 'True' if the key exists, false if key does not exist or the class instance is not open
		bool KeyExists (
			const char* KeyName
			) const;

		//! Determine if the child key exists.
		//! @return 'True' if the key exists, false if key does not exist or the class instance is not open
		bool KeyExists (
			const MISTRING& KeyName
			) const;

		//! Open a registry key given the ASCII name to the key
		ERRVALUE OpenKey (
			const char* name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key given the ASCII name to the key
		ERRVALUE OpenKey (
			const MISTRING& name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key given a base registry key and a sub-key path
		ERRVALUE OpenKey (
			BASE root,
			const char* name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key given a base registry key and a sub-key path
		ERRVALUE OpenKey (
			BASE root,
			const MISTRING& name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key given a parent key and a sub-key name
		ERRVALUE OpenKey (
			const REGISTRY& parent,
			const char* name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key given a parent key and a sub-key name
		ERRVALUE OpenKey (
			const REGISTRY& parent,
			const MISTRING& name,
			ACCESS Access = ACCESS_Read
			);

		//! Open a registry key on a remote system given a machine name.
		//! this will only work on some systems, see RegConnectRegistry() for more information
		ERRVALUE OpenRemoteKey (
			BASE root,
			const MISTRING& MachineName
			);

		//! Patch values and keys from 'this' to 'DestKey'.
		//! Will not change existing values, will patch in keys and values from 'this' that do not exist in 'DestKey'.
		ERRVALUE PatchTo (
			REGISTRY& DestKey
			);

		//! Restore a registry hive saved with the 'Save' method.
		ERRVALUE Restore (
			const FILEPATH& filename
			);

		//! Save the key and all subkeys into a file			
		ERRVALUE Save (
			const FILEPATH& filename
			) const;

		//! Setup an event to trigger if the current registry key or any of its values is changed.
		//! Once the event is triggered, the method must be called again to reset the event to be triggered.
		ERRVALUE SetChangeNotifyEvent (
			HANDLE Event
			);

		//! Set the given registry value with the given data
		//! The values are stored as "Yes' and 'No' entries in a multi-string.
		ERRVALUE SetValue (
			const char* name,
			const BITSET_UNOWNED& value
			);
		
		//! Set the given registry value with the given data
		//! The values are stored as "Yes' and 'No' entries in a multi-string.
		ERRVALUE SetValue (
			const MISTRING& name,
			const BITSET_UNOWNED& value
			);
		
		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const char* name,
			const MISTRING& value
			);
		
		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const MISTRING& name,
			const MISTRING& value
			);
		
		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const char* name,
			INT32 value
			);

		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const MISTRING& name,
			INT32 value
			);

		//! Set the given registry value with the given data
		//! Not overloaded because it will conflict with above method
		ERRVALUE SetValue64 (
			const char* name,
			INT64 value
			);

		//! Set the given registry value with the given data
		//! Not overloaded because it will conflict with above method
		ERRVALUE SetValue64 (			
			const MISTRING& name,
			INT64 value
			);

		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const char* name,
			const MISTRINGLIST& StrList
			);

		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const MISTRING& name,
			const MISTRINGLIST& StrList
			);

		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const char* name,
			const FILEPATHLIST& PathList
			);

		//! Set the given registry value with the given data
		ERRVALUE SetValue (
			const MISTRING& name,
			const FILEPATHLIST& PathList
			);

		//! Set the binary value given as a SIMPLE_ARRAY<UINT8> value.
		ERRVALUE SetValue (
			const char* name,
			const SIMPLE_ARRAY<UINT8>& binary
			);

		//! Set the binary value given as a SIMPLE_ARRAY<UINT8> value.
		ERRVALUE SetValue (
			const MISTRING& name,
			const SIMPLE_ARRAY<UINT8>& binary
			);

		//! Set the given registry value with the given data
		//! Stored as a 64 bit value from DATETIME::GetNanoTime() in UTC
		ERRVALUE SetValue (
			const char* name,
			const DATETIME& dt
			);

		//! Set the given registry value with the given data
		//! Stored as a 64 bit value from DATETIME::GetNanoTime() in UTC
		ERRVALUE SetValue (
			const MISTRING& name,
			const DATETIME& dt
			);

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT
		HKEY m_hk;
		#endif	// GENERATING_DOXYGEN_OUTPUT
	};


#undef	CLASSLIBEXPORT
#endif	// if defined(WIN32)
#endif	// INC_MI32_REGISTRY_H 

