/**
 * \file mi32/rvcdefns.h
 * \brief RVC Definitions Header File
 *
 * \if NODOC
 * $Id: rvcdefns.h_v 4.579 2012/01/19 15:45:41 mju Exp $
 *
 * $Log: rvcdefns.h_v $
 * Revision 4.579  2012/01/19 15:45:41  mju
 * Remove unused prototype.
 *
 * Revision 4.578  2011/11/04 13:46:07  mju
 * Remove redundant hdr.
 *
 * Revision 4.577  2010/08/19 13:52:09  mju
 * Move elementnum value defns to stddefns.
 *
 * Revision 4.576  2007/10/26 22:43:51  scowan
 * Updated flags and structs to be enums and rvc namespaced.
 *
 * Revision 4.575  2007/10/26 16:12:47  scowan
 * Removed unnecessary include file.
 *
 * Revision 4.574  2007/10/26 15:49:39  scowan
 * Moved the file lock info structure to own inclkude file.
 *
 * Revision 4.573  2007/10/25 20:55:44  scowan
 * Moved app name setting functions to private include file.
 *
 * Revision 4.572  2007/09/10 17:10:16  scowan
 * Replaced rvc gen info include file with sections we need.
 *
 * Revision 4.571  2007/06/29 15:09:34  scowan
 * Fixed deprecated report on unsigned type.
 *
 * Revision 4.570  2007/04/20 22:20:50  scowan
 * Removed unused function prototypes.
 *
 * Revision 4.569  2007/04/20 16:03:19  scowan
 * Added deprecated warnings for rvctype's.
 *
 * Revision 4.568  2007/04/20 15:29:36  scowan
 * Surrounded the rvctypes defines with no deprecated.
 *
 * Revision 4.567  2007/04/19 16:51:30  mju
 * Remove errhandler hdr as not needed here.
 *
 * Revision 4.566  2007/04/16 19:35:41  scowan
 * Removed unused prototype.
 *
 * Revision 4.565  2007/04/16 16:55:59  scowan
 * Moved lite test routines to static rvc object class methods.
 *
 * Revision 4.564  2007/04/13 23:08:12  scowan
 * Removed unused function .
 *
 * Revision 4.563  2007/04/11 17:44:02  scowan
 * Moved some items to another include file.
 *
 * Revision 4.562  2007/04/06 22:57:09  scowan
 * Removed unused function prototype.
 *
 * Revision 4.561  2007/04/06 21:41:58  scowan
 * Removed unused prototypes.
 *
 * Revision 4.560  2007/04/06 21:09:15  scowan
 * Added method to get project file lock state.
 *
 * Revision 4.559  2007/04/05 20:10:23  dwilliss
 * ok, so the class one does have to be different after all
 *
 * Revision 4.558  2007/04/05 19:57:52  dwilliss
 * changed dllexport defines -- special class one now same as function one and
 * should be deprecated.  Changed name to rvcsys since we havn't had rvclow
 * and rvcapp for years
 *
 * Revision 4.557  2007/04/03 15:13:32  scowan
 * Moved mem set guards to ge info include file.
 *
 * Revision 4.556  2007/04/03 14:49:11  scowan
 * Moved genlist info into rvc namespace.
 *
 * Revision 4.555  2007/04/02 22:29:18  scowan
 * *** empty log message ***
 *
 * Revision 4.554  2007/04/02 20:32:41  scowan
 * Moved resample defines and prototypes to op resample include file.
 *
 * Revision 4.553  2007/04/02 16:00:09  scowan
 * Moved raster resample prototypes to rvc defns.
 *
 * Revision 4.552  2007/04/02 15:32:48  scowan
 * Moved convert color to composite AI prototypes to rvc defns.
 *
 * Revision 4.551  2007/04/02 15:19:22  scowan
 * Moved doTHinRaster to rvc defns.
 *
 * \endif
**/

#ifndef INC_MI32_RVCDEFNS_H
#define INC_MI32_RVCDEFNS_H

#if defined (__cplusplus)

#ifndef INC_RVC_OBJECTNAME_H
	#include <rvc/objectname.h>
#endif

//! Forward declarations
namespace RVC {
	class OBJITEM;
	}

#ifndef NO_DEPRECATED	// Deprecatd 20-Apr-07 -- use RVC::RASTER::DATATYPE
/*-------------------------------------------------------------------------*/
/*		Define data types for .datatype fields											*/
/*-------------------------------------------------------------------------*/

#define	RVCTYPE_Unsigned		1			//!<  UINT8, UINT16, UINT32 and < 8 bit 
#define	RVCTYPE_Signed			2			//!<  INT8, INT16, INT32 
#define	RVCTYPE_Float			3			//!<  FLOAT, DOUBLE 
#define	RVCTYPE_RGB				8			//!<  RED, GREEN, BLUE packed (red high bits) 
#define	RVCTYPE_BGR				9			//!<  RED, GREEN, BLUE packed (blue high bits) 
#define	RVCTYPE_ComplexRI		16			//!<  Real, Imaginary 
#define	RVCTYPE_ComplexMP		17			//!<  Magnitude, Phase 

/* Due to an obsure but historical bug, 24 bit rasters are actually stored */
/* in the opposite order of what they say they are.  These #defines will */
/* allow you to account for that in a way that avoids the confusion */
#define  RVCTYPE_RGB24_Really	9			//!<  RED, GREEN, BLUE really 
#define  RVCTYPE_BGR24_Really	8			//!<  BLUE, GREEN, RED really 

#ifdef WIN32
#pragma deprecated("RVCTYPE_Unsigned")
#pragma deprecated("RVCTYPE_Signed")
#pragma deprecated("RVCTYPE_Float")
#pragma deprecated("RVCTYPE_RGB")
#pragma deprecated("RVCTYPE_BGR")
#pragma deprecated("RVCTYPE_ComplexRI")
#pragma deprecated("RVCTYPE_ComplexMP")
#pragma deprecated("RVCTYPE_RGB24_Really")
#pragma deprecated("RVCTYPE_BGR24_Really")
#endif
#endif	// NO_DEPRECATED

//!\addtogroup RVC RVC Object Funcions
//!@{

//---------------------------------------------------------------------------
//!		Function prototypes
//---------------------------------------------------------------------------

extern "C" {
//!\addtogroup RvcRast RVC Raster Functions
//!@{

//! 
//! Perform line thinning on binary raster data.
int DoThinRaster (
	INT32 numcols, 							//!< Number of columns in raster
	INT32 numlins, 							//!< Number of lines in raster
	int(*)(INT32,UINT8*,void*), 			//! Function to read line from raster
	int(*)(INT32,UINT8*,void*), 			//! Function to write line to raster
	void *Clientdata,							//!< To be passed to ReadFunc and WriteFunc
	int polyflag								//!< Something to do with polygons?
	);

//! These next two functions will eventually be a filter in the image pipeline as a neural net classifier.  Does color reduction to minimal necessary
int MfConvert24bittoComposite (const RVC::OBJITEM&, const RVC::OBJITEM&, int, int);
int MfConvertRGBtoComposite (const RVC::OBJITEM&, const RVC::OBJITEM&, const RVC::OBJITEM&, const RVC::OBJITEM&, int, int);

//! Compute raster cell values by query.
int MfComputeRasterByQuery (
	const RVC::OBJITEM& SrcItem,				//!< Source raster
	const MISTRING& QueryString,				//!< Query string
	RVC::OBJITEM& DestItem						//!< Destination instance to pass to RVC::RASTER::Make()
	);
	
//!@}

// Higher-level functions

#if defined(X_NATIVE) && !defined(NO_DEPRECATED)
//! Pop-in dialog to allow user to edit object/item name.
//! \deprecated Replaced by RVC::DlgEditDescriptor()
DEPRECATED int MfEditName (
	Widget pwidget,							//!< Parent widget
	const char *formname,					//!< Name for form dialog
	const char *labelname,					//!< Name for label
	RVC::OBJECTNAME& name,					//!< Name passed/returned
	int (*NameInUse)(const RVC::OBJECTNAME&, void*),	//! Function to check if name is in use
	void *NameInUseData,						//!< Data to pass to NameInUse function
	UINT32 flags								//!< Flags
	);
#endif

}	// extern "C"

//!@}

//-----------------------------------------------------------------------


#else		//!<  Not C++ 
#error This header requires C++ to compile.
#endif

#endif
