/**
 * \file rvc/getobjflags.h
 * \brief GETOBJFLAGS enum definition.
 *
 * \if NODOC
 * $Id: getobjflags.h_v 1.6 2011/09/02 13:07:03 mju Exp $
 *
 * $Log: getobjflags.h_v $
 * Revision 1.6  2011/09/02 13:07:03  mju
 * Exclude macro from dox.
 *
 * Revision 1.5  2009/03/03 14:16:50  mju
 * Add _AllowLinkForNew flag.
 *
 * Revision 1.1  2006/10/13 14:03:32  mju
 * Initial revision
 * \endif
**/

#ifndef	INC_RVC_GETOBJFLAGS_H
#define	INC_RVC_GETOBJFLAGS_H

#ifndef	INC_MI32_STDDEFNS_H
#include <mi32/stddefns.h>
#endif

//! Enumeration for flags used in object selection dialogs.
enum GETOBJFLAGS {
	GETOBJFLAG_None =					0x00000000,	//!< No flags set
	GETOBJFLAG_NewOK =				0x00000001,	//!< Let user create new objects
	GETOBJFLAG_SkipOK =				0x00000004,	//!< Allow user to skip this selection
	GETOBJFLAG_OnlyNew =				0x00000040,	//!< Don't let user select existing objects
	GETOBJFLAG_Overwrite =			0x00000080,	//!< Data in existing object will be overwritten
	GETOBJFLAG_AllowLinkForNew =	0x00000100,	//!< Allow "linkable" file types even if only creating new object
	GETOBJFLAG_AllowAll =			0x00000200,	//!< Allow all object types in getrvcobjs()
	GETOBJFLAG_AllowFewer =			0x00008000,	//!< Allow fewer than requested number of objects in RVC::DlgGetObjectSet()
	GETOBJFLAG_SkipNone =			0x00010000,	//!< Change "Skip" button to "None", behavior same
	GETOBJFLAG_AllowAutoName =		0x00040000,	//!< Allow "auto-name" for RVC::DlgGetObjectSet
	GETOBJFLAG_AllowDupObjs =		0x00200000,	//!< Allow duplicate objects in DlgGetObjects()
	GETOBJFLAG_NoMetaData =			0x00400000,	//!< Don't allow meta-data viewing/selection (used by meta-data editor)
	GETOBJFLAG_NoChangeLevel =		0x02000000,	//!< User can't navigate out from under initial object
	};

#ifndef GENERATING_DOXYGEN_OUTPUT
DEFINE_ENUM_OP_BITWISE(GETOBJFLAGS)
#define	GETOBJFLAG_NewOnly		GETOBJFLAG_OnlyNew
#endif

#endif	// INC_RVC_GETOBJFLAGS_H
