/**
 * \file rvc/objitem.h
 * \brief RVC::OBJITEM class definitions
 *
 * \if NODOC
 *
 * $Id: objitem.h_v 1.70 2011/11/14 20:58:42 mju Exp $
 *
 * $Log: objitem.h_v $
 * Revision 1.70  2011/11/14 20:58:42  mju
 * Add setTitle/URL.
 *
 * Revision 1.69  2011/07/20 20:55:05  mju
 * Make setFilePath non-inline.
 *
 * Revision 1.68  2010/11/19 22:50:15  bcolombe
 * Added TYPE_URL
 * Added ctor for URL
 * Added Title
 *
 * Revision 1.67  2010/06/15 14:04:58  mju
 * Change isFileOnly to check specific 0 and -2 for objectInode.
 *
 * Revision 1.66  2009/11/12 17:13:56  mju
 * Add getIconIdFromObjectType and getIconID.
 *
 * Revision 1.65  2009/11/02 14:23:38  mju
 * Remove credentials versions of IsNew/SkipRequest.
 *
 * Revision 1.64  2009/10/30 17:48:28  mju
 * Make some methods non-inline.
 *
 * Revision 1.63  2009/10/19 18:09:22  mju
 * Add getDisplayPath, getType, setFromDisplayPath.
 *
 * Revision 1.62  2009/04/20 17:28:35  mju
 * Add isFileNonRVC.
 *
 * Revision 1.61  2008/11/17 21:11:04  mju
 * Exclude setItem and getParentInode except from rvcsys dll.
 * Use no_deprecated from legacy ctor - comment from Steve said wait until 74, so since 75 assumed safe.
 *
 * Revision 1.60  2008/09/04 13:36:41  mju
 * Fix doxygen warnings.
 *
 * Revision 1.59  2007/10/01 15:36:44  scowan
 * Made some more friends.
 *
 * Revision 1.58  2007/09/28 23:10:16  scowan
 * Removed inclusion of list container for objitem.
 *
 * Revision 1.57  2007/08/17 21:40:35  mju
 * Remove unnecessary qualifier.
 *
 * Revision 1.56  2007/07/31 13:11:06  mju
 * Add dft for credentials on isObjectExtFile.
 *
 * Revision 1.55  2007/07/20 22:28:51  scowan
 * Removed use of rvc gen info.
 *
 * Revision 1.54  2007/07/13 19:32:48  mju
 * Add isObjectExtFile.
 *
 * Revision 1.53  2007/05/10 19:43:36  mju
 * Don't include milist as done (with deprecation) by objitemlist hdr.
 *
 * Revision 1.52  2007/05/09 15:29:47  mju
 * Deprecate inclusion of objitemlist hdr.
 *
 * Revision 1.51  2007/05/08 13:10:45  mju
 * Don't doxy objitemlist inclusion.
 *
 * Revision 1.50  2007/05/08 13:07:26  mju
 * Move objitemlist to own hdr.
 *
 * Revision 1.49  2007/05/08 12:57:42  mju
 * Move objitemlist to own hdr.
 *
 * Revision 1.48  2007/04/03 15:32:05  scowan
 * Removed the no deprecated defines around the legacy inode ctor version with a comment to only re-add in the 7.4 code.
 *
 * Revision 1.47  2007/04/03 13:43:17  mju
 * Remove unused getName and getDescription.
 *
 * Revision 1.46  2007/02/20 17:35:24  mju
 * Add createNew using just descriptor and option objtype.
 *
 * Revision 1.45  2007/02/13 17:24:50  mju
 * Remove unused legacy setObjectName/Description fns.
 *
 * Revision 1.44  2007/01/02 19:08:09  scowan
 * Added credentials.
 *
 * Revision 1.43  2006/12/08 14:40:12  mju
 * Only allow setObjectInfo in rvcsys dll.
 *
 * Revision 1.42  2006/11/07 22:46:51  dwilliss
 * Change is file only so if the inode is invalid (<0), it's only a file
 *
 * Revision 1.41  2006/10/25 21:33:04  mju
 * Add locateRelated method.
 *
 * Revision 1.40  2006/10/16 16:33:51  mju
 * No longer include rvcdefns hdr.
 *
 * Revision 1.39  2006/10/13 21:21:13  mju
 * Use rvcgeninfo hdr, only include rvcdefns if not no_deprecated.
 *
 * Revision 1.38  2006/09/28 22:28:14  scowan
 * Deprecated pre namespace objitem typedef's.
 *
 * Revision 1.37  2006/09/28 17:42:43  scowan
 * Upgraded objitemlist to a class.
 *
 * Revision 1.36  2006/08/18 21:43:16  mju
 * Add getObjectDisplayPath.
 *
 * Revision 1.35  2006/07/21 17:17:02  mju
 * Add getDisplay/ToolTipString variants that return string by value.
 *
 * Revision 1.34  2006/01/25 14:46:57  mju
 * Don't pragma dll warning as done in stddefns.
 *
 * Revision 1.33  2005/11/17 15:23:35  mju
 * Add deprecation comments.
 * Add getObjectDescriptor, deprecate getDescriptor.
 * Exclude all deprecated methods if deprecate_all defined.
 *
 * Revision 1.32  2005/11/10 17:22:33  scowan
 * Uninlined methods that VC++ does not inline.
 *
 * Revision 1.31  2005/11/10 16:38:35  scowan
 * Uninlined the dtor because the compiler will not inline it.
 *
 * Revision 1.16  2005/05/02 17:53:44  dwilliss
 * SetObjectPath should resolve the object inode
 *
 * Revision 1.15  2005/05/02 14:58:08  dwilliss
 * Added Get/SetCombinedPath
 *
 * Revision 1.14  2005/03/31 16:57:27  fileserver!dwilliss
 * Rename one of our types to MIUNICODE because it conflicted with a Microsoft #define
 *
 * Revision 1.13  2005/03/08 23:42:44  mju
 * Add setSkipRequest.
 *
 * Revision 1.12  2005/02/07 21:55:23  scowan
 * Fixed g++ warning in get objec type method.
 *
 * Revision 1.9  2005/01/31 20:14:05  scowan
 * Added two methods to check for skip and new requests.
 *
 * Revision 1.8  2005/01/18 21:23:51  scowan
 * Removed changes for mi string variants.
 * Added descriptor variants.
 * Warning deprecated many methods for now.
 *
 * Revision 1.1  2004/07/22 14:31:00  mju
 * Initial revision
 * \endif
**/

#ifndef	INC_RVC_OBJITEM_H
#define	INC_RVC_OBJITEM_H

#ifndef	INC_RVC_DESCRIPTOR_H
#include <rvc/descriptor.h>
#endif

#ifndef	INC_RVC_OBJTYPE_H
#include <rvc/objtype.h>
#endif

#ifndef	INC_MI32_FILEPATH_H
#include <mi32/filepath.h>
#endif

#ifndef	INC_MI32_FILEFIND_H
#include <mi32/filefind.h>
#endif

#ifndef	INC_MI32_ICONID_H
#include <mi32/iconid.h>
#endif

#ifdef RVCSYSDLL
	#define CLASSEXPORT MI_DLLCLASSEXPORT
#else
	#define CLASSEXPORT MI_DLLCLASSIMPORT
#endif

namespace RVC {
#ifndef GENERATING_DOXYGEN_OUTPUT
class CREDENTIALS;
class OBJECT;
class OBJITEMLIST;
class OBJMAKEPARMS;
class OBJOPENPARMS;
#endif // GENERATING_DOXYGEN_OUTPUT

//=====================================================================================================================

//! OBJITEM class for specifying a particular file and object.
class CLASSEXPORT OBJITEM {
	public:

		//! General item type enumeration.
		enum TYPE {
			TYPE_Empty =				0,		//!< Empty
			TYPE_Invalid =				1,		//!< Invalid location
			TYPE_General_Folder =	2,		//!< Existing filesystem folder
			TYPE_General_File =		3,		//!< Existing or new general (non-RVC) file
			TYPE_RVC_File =			4,		//!< Existing or new RVC file (RVC::OBJTYPE_File)
			TYPE_RVC_Folder =			5,		//!< Existing or new RVC folder (RVC::OBJTYPE_Folder)
			TYPE_RVC_Object =			6,		//!< Existing or new RVC object (not OBJTYPE_File or OBJTYPE_Folder)
			TYPE_URL =					7,		//!< URL
			};

		static ICONID GetIconIdFromObjectType (
			OBJTYPE objtype
			);

		//! Setup output object item list corresponding to specified input object item list.
		static void SetupOutputList (
			OBJITEMLIST& oobjlist,				//!< Output list
			const OBJITEMLIST& iobjlist,		//!< Input list
			const char *source = 0				//!< Value to use for "source" in object header, will use application name if null.
			);

		//! Default constructor.
		OBJITEM (
			);

		//! Copy constructor.
		OBJITEM (
			const OBJITEM& rhs					//!< Object to copy from
			);

		//! Construct from FILEPATH and object path string.
		OBJITEM (
			const FILEPATH& filename,			//!< Filename
			const MISTRING& ObjectPath			//!< Object path
			);

		//! Consturct from URL, Title, ObjType
		OBJITEM (
			const MISTRING& URL,				//!< URL
			const MISTRING& Title,				//!< Title
			const RVC::OBJTYPE& ObjType			//!< ObjType
			);

	#ifndef NO_DEPRECATED
		//! Construct from FILEPATH and object inode.
		//! \deprecated Use version with object path.
		DEPRECATED OBJITEM (
			const FILEPATH& filename,				//!< Filename
			RVCINODENUM inode,						//!< Object inode
			const CREDENTIALS *pCredentials = 0
			);
	#endif

		//! Construct having specified name, description, optional source.
		//! This useful when setting up an "output" OBJITEMLIST.
		OBJITEM (
			const DESCRIPTOR& Descriptor
			);

		//! Default destructor			
		~OBJITEM (
			);

		//! Assignment.
		OBJITEM operator= (
			const OBJITEM& rhs					//!< Object to copy from
			);

		//! Assignment.
		OBJITEM& operator= (
			const DESCRIPTOR& Descriptor
			);
			
		//! Clear the OBJITEM, refers to nothing
		void Clear (
			);

		//! Setup for use in prompt for or creation of new object with unspecified parent.
		//! Does not alter currently set filepath.
		void CreateNew (
			const DESCRIPTOR& Descriptor,			//!< New object descriptor
			RVC::OBJTYPE ObjType = RVC::OBJTYPE_All	//!< New object type
			);

		//! Setup for use in prompt for or creation of new object with RVC::OBJITEM parent.
		void CreateNew (
			const RVC::OBJITEM& ParentItem,		//!< Parent object item reference
			RVC::OBJTYPE ObjType,					//!< New object type
			const DESCRIPTOR& Descriptor			//!< New object descriptor
			);

		//! Setup as new non-RVC file.
		void CreateNewFileNonRVC (
			const FILEPATH& filepath
			);

		//! Get the Combined Path.
		//! This returns a string with the filepath and object path as as single
		//! string.  Use SetCombinedPath to set an OBJITEM using a string of this
		//! format.
		ERRVALUE GetCombinedPath (
			MISTRING& CombinedPath,
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Get display path, suitable for editing by user.
		//! Display path uses / as separator between folders, file name and RVC folders.
		//! Not recommended for non-folder RVC objects.
		//! @seealso SetFromDisplayPath.
		void GetDisplayPath (
			MISTRING& pathstr,
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Get string suitable for display.
		//! String will consist of file name, separator and object name.
		//! @see GetToolTipString
		void GetDisplayString (
			MISTRING& string,							//!< String returned
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Return string suitable for display.
		//! String will consist of file name, separator and object name.
		//! @see GetToolTipString
		MISTRING GetDisplayString (
			const CREDENTIALS *pCredentials = 0
			) const { MISTRING str; GetDisplayString(str, pCredentials); return (str); }

		//! Get the filepath.
		const FILEPATH& GetFilePath (
			) const { return (m_filename); }

		//! Get icon ID.
		ICONID GetIconID (
			) const;

	#ifndef NO_DEPRECATED
		//! Get the inode.
		//! \deprecated Avoid use of INODENUM
		DEPRECATED RVCINODENUM GetInode (
			const CREDENTIALS *pCredentials = 0
			) const {
			if (!IsResolved()) ResolveObjectPath(pCredentials);
			return (m_ObjectInode);
			}
	#endif

		//! Get the RVC::DESCRIPTOR of the object represented by this instance
		//! @return DESCRIPTOR instance containing the name and description of the object
		const DESCRIPTOR& GetObjectDescriptor (
			const CREDENTIALS *pCredentials = 0
			) const { 
			if (!IsResolved()) ResolveObjectPath(pCredentials);
			return (m_Descriptor); 
			}

		//! Get string suitable for displaying object path.
		//! Will be one-line string.  Containing folder will be shown with no "type" suffix.
		//! Containing object(s) will show with type in parentheses.
		//! Object itself will not show with type suffix.
		void GetObjectDisplayPath (
			MISTRING& string,							//!< String returned
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Get the Object Path
		ERRVALUE GetObjectPath (
			MISTRING& ObjectPath,
			const CREDENTIALS *pCredentials = 0
			) const {
			if (m_ObjectInode == -1) {
				ObjectPath = m_ObjectPath;
				return (0);
				}
			return (DetermineObjectPath(ObjectPath, pCredentials));
			}

		//! Get the object type.
		RVC::OBJTYPE GetObjectType (
			) const;

		//! Get the parent object item for 'this'
		//! @return 'True' if the parent is valid, 'false' if not
		bool GetParent (
			OBJITEM& ParentObjItem,
			const CREDENTIALS *pCredentials = 0
			) const;

	#if defined(RVCSYSDLL) && !defined(NO_DEPRECATED)
		//! Get the inode.
		//! \deprecated Avoid use of INODENUM
		DEPRECATED RVCINODENUM GetParentInode (
			const CREDENTIALS *pCredentials = 0
			) const {
			if (!IsResolved()) ResolveObjectPath(pCredentials);
			return (m_ParentInode);
			}
	#endif

		//! Get the object's URL
		const MISTRING& GetURL (
			) const { 
			if (GetType() != TYPE_URL) return MISTRING::GetEmpty();
			return (m_ObjectPath);
			}

		//! Get standard "ToolTip" string for this item.
		//! Returned string will contain multiple lines.
		//! @see GetDisplayString.
		void GetToolTipString (
			MISTRING& string,						//!< Tooltip string returned
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Get the object's Title
		const MISTRING& GetTitle (
			) const { return (m_Title); }

		//! Return standard "ToolTip" string for this item.
		//! Returned string will contain multiple lines.
		//! @see GetDisplayString.
		MISTRING GetToolTipString (
			const CREDENTIALS *pCredentials = 0
			) const { MISTRING str; GetToolTipString(str, pCredentials); return (str); }

		//! Get general item type.
		OBJITEM::TYPE GetType (
			) const;

		//! Determine if has object description.
		bool HasObjectDescription (
			const CREDENTIALS *pCredentials = 0
			) const {
			if (!IsResolved()) ResolveObjectPath(pCredentials);
			return (!m_Descriptor.GetDescription().IsEmpty());
			}
			
		//! Determine if the two OBJITEM's have the same parent object
		bool HasSameParent (
			const OBJITEM& rhs
			) const { return (m_filename == rhs.m_filename && m_ParentInode == rhs.m_ParentInode); }

		//! Read from .ini file.
		//! @return true if entry exists in .ini file, false if not.
		bool IniRead (
			INIHANDLE handle,							//!< Ini Handle created by IniOpen()
			const char *group,						//!< Group to look for ini entry, App Name if =0
			const char *field							//!< Field to read string from
			);

		//! Write to .ini file.
		void IniWrite (
			INIHANDLE handle,							//!< Ini Handle created by IniOpen()
			const char *group,						//!< Group to write ini entry, App Name if =0
			const char *field,						//!< Field to write string to
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Determine if have both filepath and "object" assigned.
		//! Does not determine if actually resolved to existing object.
		bool IsAssigned (
			) const;

		//! Is it the same?
		bool IsEqual (
			const OBJITEM& rhs,				//!< Object to compare
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Determine if item references actual existing object.
		//! This should not be used in time-critical operations as it will actually
		//! open the file and verify that the object exists.
		bool IsExisting (
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Determine if assigned file is non-RVC format.
		bool IsFileNonRVC (
			) const;

		//! Determine if item references the file level.
		bool IsFileOnly (
			) const { return (!m_filename.IsEmpty() && (m_ObjectInode == 0 || m_ObjectInode == -2)); }

		//! Determine if item is less than 'rhs'
		//! Needed for export of OBJITEMLIST from dll
		bool IsLessThan (
			const OBJITEM& rhs
			) const;
			
		//! Determine if item is less than 'rhs' according to child ordering
		bool IsLessThanChild (
			const OBJITEM& rhs
			) const { return (m_ObjectInode < rhs.m_ObjectInode); }
			
		//! Determine if item is built from a new object request from DlgGetObject()
		bool IsNewRequest (
			) const { return (m_ObjectInode == R_NewRequest); }

		//! Determine if assigned "object" actually refers to external (non-RVC) file.
		bool IsObjectExtFile (
			const CREDENTIALS *pCredentials = 0
			) const;

		//! Determine if has been resolved to specific existing object.
		bool IsResolved (
			) const;
			
		//! Determine if item is built from a skip object request from DlgGetObject()
		bool IsSkipRequest (
			) const { return (m_ObjectInode == R_SkipRequest); }

		//! Locate item by search relative to specified source path.
		//! Will use current file and object paths as items to search for, and if successful
		//! the current instance will be set to the located object.
		//! @return 'true' if located, false if not
		bool LocateRelated (
			const FILEPATH& SourcePath,					//!< Path to source file or starting folder
			FILEFIND::RELATEDORDER order,					//!< Folder search order
			const CREDENTIALS *pCredentials = 0
			);

		//! Set the Combined Path.
		//! This sets up an ObjItem given a string encoded by GetCombinedPath
		void SetCombinedPath (
			const MISTRING& CombinedPath,
			const CREDENTIALS *pCredentials = 0
			); 

		//! Set file path.
		void SetFilePath (
			const FILEPATH& filepath
			);

		//! Set from "display path".
		//! Display path uses / as separator between folders, file name and RVC folders.
		//! @return true if set to existing location, false if not.
		bool SetFromDisplayPath (
			const MISTRING& pathstr,
			const CREDENTIALS *pCredentials = 0
			);

		//! Set item from FILEPATH and object path.
		void SetItem (
			const FILEPATH& filename,			//!< File name
			const MISTRING& ObjectPath			//!< Object path
			);

	#if defined(RVCSYSDLL) && !defined(NO_DEPRECATED)
		//! Set item from FILEPATH and object inode.
		//! \deprecated Do not use legacy INODENUM
		DEPRECATED void SetItem (
			const FILEPATH& filename,			//!< File name
			RVCINODENUM inode,					//!< Object inode
			const CREDENTIALS *pCredentials = 0
			);
	#endif

		//! Set item from FILEPATH only, must be an rvc file
		void SetItemToFile (
			const FILEPATH& filename,			//!< File name
			const CREDENTIALS *pCredentials = 0
			);

		//! Set object descriptor.
		void SetObjectDescriptor (
			const DESCRIPTOR& NewDescriptor
			);

		//! Set object path without clearing file path.
		void SetObjectPath (
			const MISTRING& ObjectPath,			//!< Object path
			const CREDENTIALS *pCredentials = 0
			);

		//! Set object type if not bound to an object.
		void SetObjectType (
			OBJTYPE objtype							//!< Object type
			) { if (m_ObjectInode < 0) m_ObjType = objtype; }

		//! Set item to be 'skip' request.
		void SetSkipRequest ();

		//! Set "title" (typically only used for URL).
		void SetTitle (
			const MISTRING& title					//!< Title string
			) { m_Title = title; }

		//! Set item to reference URL.
		void SetURL (
			const MISTRING& url,									//!< URL string
			RVC::OBJTYPE ObjType = RVC::OBJTYPE_Remote	//!< Remote object type
			);

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT

		FILEPATH m_filename;						// File name
		mutable RVCINODENUM m_ObjectInode;
		mutable RVCINODENUM m_ParentInode;
		mutable OBJTYPE m_ObjType;
		MISTRING m_ObjectPath;					// Object path
		mutable DESCRIPTOR m_Descriptor;		// Object name, desc, and source
		MISTRING m_Title;							// Object title

		// Determine object path from m_ginfo.
		ERRVALUE DetermineObjectPath (MISTRING& ObjectPath, const CREDENTIALS *pCredentials) const;

		// Resolve object path and setup m_ginfo.
		void ResolveObjectPath (const CREDENTIALS *pCredentials) const;

		friend class OBJECT;
		friend class OBJMAKEPARMS;
		friend class OBJOPENPARMS;
		#endif // GENERATING_DOXYGEN_OUTPUT
	};


//! Equality operator.
inline bool operator== (
	const RVC::OBJITEM& lhs,				//!< Object to compare
	const RVC::OBJITEM& rhs					//!< Object to compare
	) {
	return (lhs.IsEqual(rhs));
	}

//! Inequality operator.
inline bool operator!= (
	const RVC::OBJITEM& lhs,				//!< Object to compare
	const RVC::OBJITEM& rhs					//!< Object to compare
	) {
	return (!lhs.IsEqual(rhs));
	}

//! Compare two OBJITEMS for less than.
inline bool operator< (						
	const RVC::OBJITEM& lhs,
	const RVC::OBJITEM& rhs
	) { return (lhs.IsLessThan(rhs)); }
	
//=====================================================================================================================

}		// End namespace RVC

#undef CLASSEXPORT

#endif	// INC_RVC_OBJITEM_H

