/**
 * \file rvc/oprasterthreshold.h
 * \brief RVC::OP::RASTER_THRESHOLD definitions
 *
 * \if NODOC
 * $Id: oprasterthreshold.h_v 1.2 2006/11/17 21:56:39 mju Exp $
 *
 * $Log: oprasterthreshold.h_v $
 * Revision 1.2  2006/11/17 21:56:39  mju
 * Add optional rectangle parm to process methods.
 *
 * Revision 1.1  2006/11/16 20:38:54  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_RVC_OPRASTERTHRESHOLD_H
#define	INC_RVC_OPRASTERTHRESHOLD_H

#ifndef	INC_MI32_STDDEFNS_H
#include <mi32/stddefns.h>
#endif

namespace RVC {

class OBJITEM;
class RASTER;

namespace OP {

//! Class to perform raster thresholding.
class RASTER_THRESHOLD {
	public:

		//! Flags to control processing
		enum FLAGS {
			FLAG_None =					0x00,
			FLAG_OutputBelowAs1 =	0x01,		//!< Output 1 for values below threshold, default is to output 1 if above
			FLAG_OutputNullAs1 =		0x02,		//!< Output 1 for null cells, default is to output 0 for null cells
			FLAG_KeepNulls =			0x04		//!< Keep null cells from source, default is to discard nulls
			};

		static ERRVALUE Process (
			RVC::RASTER& ObjSrcRaster,					//!< Source raster
			RVC::RASTER& ObjTgtRaster,					//!< Target raster, must be binary with same dimensions as source raster/rectangle
			double threshold,								//!< Threshold value
			FLAGS flags = FLAG_None,
			const LRECT2D *pSrcRect = 0				//!< Source rectangle, NULL for entire source raster
			);

		static ERRVALUE Process (
			const RVC::OBJITEM& ObjItemSrcRaster,	//!< Source raster location
			RVC::OBJITEM& ObjItemTgtRaster,			//!< Target raster location, if exists must be binary with same dimensions as source raster/rectangle
			double threshold,								//!< Threshold value
			FLAGS flags = FLAG_None,
			const LRECT2D *pSrcRect = 0				//!< Source rectangle, NULL for entire source raster
			);

	};

#ifndef GENERATING_DOXYGEN_OUTPUT
DEFINE_ENUM_OP_BITWISE(RASTER_THRESHOLD::FLAGS)
#endif

}	// End namespace OP
}	// End namespace RVC

#endif	// INC_RVC_OPRASTERTHRESHOLD_H
