/**
 * \file spatmod/imagefilterpixeltable.h
 * \brief Spatial Modelling (SPATMOD) IMAGE::FILTER_PIXELTABLE definition.
 *
 * \if NODOC
 *
 * $Id: imagefilterpixeltable.h_v 1.2 2007/01/02 22:31:13 mju Exp $
 *
 * $Log: imagefilterpixeltable.h_v $
 * Revision 1.2  2007/01/02 22:31:13  mju
 * Add ctor with option to take ownership of pixel table.
 *
 * Revision 1.1  2006/11/03 18:06:02  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_SPATMOD_IMAGEFILTERPIXELTABLE_H
#define	INC_SPATMOD_IMAGEFILTERPIXELTABLE_H

#ifndef	INC_SPATMOD_IMAGEFILTER_H
#include <spatmod/imagefilter.h>
#endif

namespace SPATMOD {
namespace IMAGE {

class PIXELTABLE;

//=====================================================================================================================

//! Filter to apply PIXELTABLE to image.
//! The input stage must have a single sample and should have an unsigned data type.
class FILTER_PIXELTABLE : public FILTER {
	public:

		//! Constructor.
		FILTER_PIXELTABLE (
			STAGE *pPreviousStage,					//!< Pointer to previous stage
			bool TakeOwnership,						//!< Filter takes ownership of previous stage and will delete when needed
			const PIXELTABLE& PixelTable			//!< Pixel lookup table
			);

		//! Constructor with option to take ownership of specified pixel table.
		FILTER_PIXELTABLE (
			STAGE *pPreviousStage,					//!< Pointer to previous stage
			bool TakeOwnership,						//!< Filter takes ownership of previous stage and will delete when needed
			PIXELTABLE& PixelTable,					//!< Pixel lookup table
			bool TakeTableOwnership					//!< Whether to take ownership of table (more efficient if do so)
			);

		//! Destructor.
		virtual ~FILTER_PIXELTABLE ();

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT
		// STAGE overrides.
		virtual ERRVALUE v_PullSubSection (const SECTION& SubSection, BUFFER& buffer);
		virtual ERRVALUE v_Initialize ();

		// Unimplemented
		FILTER_PIXELTABLE (const FILTER_PIXELTABLE&);
		FILTER_PIXELTABLE& operator= (const FILTER_PIXELTABLE&);
		#endif // GENERATING_DOXYGEN_OUTPUT

	};

//=====================================================================================================================

}	// End namespace IMAGE
}	// End namespace SPATMOD

#endif	// INC_SPATMOD_IMAGEFILTERPIXELTABLE_H

