/**
 * \file spatmod/imagetargettilesetnasaworldwind.h
 * \brief Spatial Modelling (SPATMOD) IMAGE::TARGET_TILESET_NASAWORLDWIND definition.
 *
 * \if NODOC
 * $Id: imagetargettilesetnasaworldwind.h_v 1.15 2011/10/11 15:04:02 mju Exp $
 *
 * $Log: imagetargettilesetnasaworldwind.h_v $
 * Revision 1.15  2011/10/11 15:04:02  mju
 * Remove textid hdr.
 *
 * Revision 1.14  2011/04/20 23:17:48  bcolombe
 * Add ResampleMethod for reduced levels
 *
 * Revision 1.13  2011/04/14 16:43:39  bcolombe
 * Remove extents from ctor, determine from input
 *
 * Revision 1.12  2010/11/01 22:45:56  bcolombe
 * Imgformat changes
 *
 * Revision 1.11  2010/06/25 16:28:50  bcolombe
 * Add UsePalette to ComputeReduced
 *
 * Revision 1.10  2010/05/18 16:48:01  bcolombe
 * Add ComputeReducedLevel that takes source & target locations
 *
 * Revision 1.9  2010/04/20 22:33:26  bcolombe
 * Add zipoutput to ComputeReducedLevel
 *
 * Revision 1.8  2010/04/19 16:25:53  bcolombe
 * Added OverwriteExisting to CreateXML
 *
 * Revision 1.7  2010/04/02 22:26:35  bcolombe
 * Make CreateXML and ComptueReducedLevel static
 *
 * Revision 1.6  2010/03/18 16:04:04  bcolombe
 * Change to constructor
 *
 * Revision 1.5  2009/12/03 21:56:52  bcolombe
 * Added optional message to ComputeReducedLevel
 *
 * Revision 1.4  2009/11/04 23:46:41  bcolombe
 * Constructor takes basepath instead of xmlpath
 *
 * Revision 1.3  2009/11/04 21:28:39  bcolombe
 * Change description of filepath in constructor
 *
 * Revision 1.2  2009/09/01 16:16:40  bcolombe
 * Added CreateXML
 *
 * Revision 1.1  2009/08/31 18:20:50  bcolombe
 * Initial revision
 *
 * Revision 1.1  2009/08/28 08:31:39  bcolombe
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_SPATMOD_IMAGETARGETTILESETNASAWORLDWIND_H
#define	INC_SPATMOD_IMAGETARGETTILESETNASAWORLDWIND_H

#ifndef	INC_SPATMOD_IMAGETARGETTILESETFILE_H
#include <spatmod/imagetargettilesetfile.h>
#endif

class MISTATUSCONTEXT;

namespace SPATMOD {
namespace IMAGE {

//=====================================================================================================================

//! Google Maps target.
class TARGET_TILESET_NASAWORLDWIND : public TARGET_TILESET_FILE {
	public:

		//! Create GoogleMaps HTML file
		static ERRVALUE CreateXML (
			TILESET& Tileset,							//!< Tileset to use
			bool bOverwriteExisting = true				//!< Write over any existing files
			);

		//! Compute reduced level (tiles must exist at zoom level + 1)
		static ERRVALUE ComputeReducedLevel (
			TILESET& Tileset,									//!< Tileset to use
			INT32 level,										//!< Level to compute
			MISTRING message = TEXTID_Creating_ResolutionLevelN	//!< Context message to display
			);

		//! Compute reduced level (tiles must exist at zoom level + 1)
		static ERRVALUE ComputeReducedLevel (
			TILESET& Tileset,									//!< Tileset to use
			const FILEPATH& SourcePath,							//!< Location of source tiles
			const FILEPATH& TargetPath,							//!< Location to output tiles
			INT32 level,										//!< Level to compute
			MISTRING message = TEXTID_Creating_ResolutionLevelN	//!< Context message to display
			);

		//! Compute reduced level (tiles must exist at zoom level + 1)
		static ERRVALUE ComputeReducedLevel (
			TILESET& Tileset,									//!< Tileset to use
			INT32 level,										//!< Level to compute
			TILESET::IMGFORMAT ImgFormat = TILESET::IMGFORMAT_Invalid,	//!< ImgFormat
			UINT16 QualityJPEG = 75,							//!< Quality of JPEG output
			MISTRING message = TEXTID_Creating_ResolutionLevelN,//!< Context message to display
			bool bZipOutput = false								//!< Zip results
			);

		//! Compute reduced level (tiles must exist at zoom level + 1)
		static ERRVALUE ComputeReducedLevel (
			TILESET& Tileset,									//!< Tileset to use
			const FILEPATH& SourcePath,							//!< Location of source tiles
			const FILEPATH& TargetPath,							//!< Location to output tiles
			INT32 level,										//!< Level to compute
			TILESET::IMGFORMAT ImgFormat,						//!< ImgFormat
			const IMAGE::PIXEL& PixelProperties,				//!< Pixel Properties
			UINT16 QualityJPEG = 75,							//!< Quality of JPEG output
			MISTRING message = TEXTID_Creating_ResolutionLevelN,//!< Context message to display
			bool bZipOutput = false,								//!< Zip results
			RESAMPLEMETHOD ResampleMethod = RESAMPLEMETHOD_Nearest	//!< Resample Method to use for zoom filter
			);

		//! Construct target.
		TARGET_TILESET_NASAWORLDWIND (
			STAGE *pInputStage,					//!< Stage in pipeline to obtain image data from
			TILESET::IMGFORMAT format,			//!< Image tile file format
			const FILEPATH& filepath,			//!< Basepath used for creating TSD and XML files
			INT32 MinLevel,						//!< Minimum Zoom Level
			INT32 MaxLevel						//!< Maximum Zoom Level
			);

		//! Destructor.
		virtual ~TARGET_TILESET_NASAWORLDWIND ();

		//! Set parameters specific to JPEG format.
		void SetParmsJPEG (
			INT16 quality
			) { m_QualityJPEG = quality; }

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT

		class IMAGENASAWORLDWIND;

		FILEPATH m_basepath;
		UINT16 m_QualityJPEG;
		MISTATUSCONTEXT *m_pStatusContext;

		// TARGET overrides.
		virtual ERRVALUE v_Initialize ();
		virtual ERRVALUE v_PushBegin (const SECTION_ITERATOR& iterator);
		virtual ERRVALUE v_PushEnd ();

		// TARGET_TILESET_FILE overrides.
		ERRVALUE v_CreateTargetFile (IMAGE::STAGE *pStageInput, const FILEPATH& filepath, const IMAGE::FORMAT& format, IMAGE::TARGET_FILE *& pTargetFile) const;
		const IMAGE::FORMAT* v_FindTileFile (FILEPATH& filepath, const LPOINT3D& TileIdx) const;
		ERRVALUE v_GenerateTileFilePath (FILEPATH& filepath, const LPOINT3D& TileIdx, bool HasNullCells, bool CreateFolder) const;

		// Unimplemented
		TARGET_TILESET_NASAWORLDWIND (const TARGET_TILESET_NASAWORLDWIND&);
		TARGET_TILESET_NASAWORLDWIND& operator= (const TARGET_TILESET_NASAWORLDWIND&);
		#endif // GENERATING_DOXYGEN_OUTPUT

	};

//=====================================================================================================================

}	// End namespace IMAGE
}	// End namespace SPATMOD

#endif	// INC_SPATMOD_IMAGETARGETTILESETNASAWORLDWIND_H

